#HF-C-TREES-GMR (Growth, Mortality & Recruitment)
# script to read, format, and combine tree data. For individually tagged tree datasets, includes mortality & recruitment also.
#Includes the following 14 data sets (* are data sets that do NOT have individually tagged trees)
#hf002  sim-hurricane (1990-2015)
#hf008	chronicN (1989-2008)
#hf031  hemlock woodlot (1990-2014)
#hf032	lyford-grid (1969-2011)
#hf036  mapped-tree-plot (1990-2013)
#hf039*	ph-veg (1937, 1992, 2013)
#hf041*	pisgah (1990-2014)
#hf053	hemlock history (1995-2012)
#hf069	ems (1993-2014)
#hf126	hf-here (2004-2014)
#hf149	hk 
#hf162*	p.biodiv (2007-2012)
#hf175	hf.regen
#hf213	demography-carb

#modified from a script written by L. Nicoll, Sept 2014 & revised Jan 2015, April 2016 & Nov 2016 by A. Barker Plotkin
#September 2017 revisions ABP. Goals: add dbhprior for recruits based on minimum dbh per study.

#note that different projects use different minimum dbh requirements for tree measurement

### COLUMN ADDED. YEAR1. FOR MOST, YEAR1 = YEAR. FOR HF032, 1987-1991-1992=1991. FOR HF126, 2003-2004-2005-2006=2004.
### FOR 'COND' PROJECT EMS-UNDERSTORY, COND CHANGED FROM NA TO L

setwd('C:/Documents and Settings/aabarker/My Documents/Dropbox/HF C Synthesis/Data/live trees/live tree data & code/')
library(reshape2)
library(plyr) 
library(RCurl)

#HF031 Hemlock Woodlot. Minimum diameter is 5 cm
hf031_url<-getURL("http://harvardforest.fas.harvard.edu/sites/harvardforest.fas.harvard.edu/files/data/p03/hf031/hf031-01-tree.csv")
tree031wide<-read.csv(text=hf031_url)
#or, get from dropbox:  tree031wide<-read.csv("hf031-01-tree.csv")

names(tree031wide)

#are there live trees missing a measurement?
miss909909<-subset(tree031wide, tree031wide$cond89!='D' & is.na(tree031wide$dbh99) & tree031wide$cond09!='D')
miss990914<-subset(tree031wide, tree031wide$cond99!='D' & is.na(tree031wide$dbh09) & tree031wide$cond14!='D')
#Nope!

#1990. Need only the live subset.
tree031.1990<-tree031wide[,c(1,5,6:7)]
  #tree77 incorrectly coded as D in 1990. Change. Actually dead in 2009, 2014.
tree031L.1990<-subset(tree031.1990, tree031.1990$cond89 %in% c("L", "M"))
tree031.77<-subset(tree031.1990, tree031.1990$tree==77)
tree031L.1990<-rbind(tree031L.1990, tree031.77)
tree031L.1990$cond89<-"L"
tree031L.1990$year<-1990
tree031L.1990$interval<-NA
tree031L.1990$dbhprior<-NA
summary(tree031L.1990)
tree031L.1990<- rename(tree031L.1990,c('spec'='species',"dbh90"="dbh", "cond89"="cond"))

#1999. Need: 1) growth (live 90 & 99); 2) recruits; 3) mortality (live 90 & dead 99)
tree031.1999<-tree031wide[,c('tree','spec','dbh90','cond89', 'dbh99', 'cond99')]
tree031D.1999<-subset(tree031.1999, tree031.1999$cond89 %in% c("L", "M") & tree031.1999$cond99 %in% c("D", "G"))
tree031D.1999$cond99<-"M"
tree031L.1999<-subset(tree031.1999, tree031.1999$cond99 %in%c("L", "M") & !is.na(tree031.1999$cond89))
tree031L.1999$cond99<-"L"
tree031R.1999<-subset(tree031.1999, tree031.1999$cond99 %in%c("L", "M") & is.na(tree031.1999$cond89))
tree031R.1999$cond99<-"R"
tree031.1999<-rbind(tree031L.1999,tree031D.1999,tree031R.1999)
tree031.1999$year<-1999
tree031.1999$interval<-1999-1990
tree031.1999$dbhprior<-ifelse(tree031.1999$cond99=='R', 5, tree031.1999$dbh90)
tree031.1999<- rename(tree031.1999,c('spec'='species',"dbh99"="dbh", "cond99"="cond"))
tree031.1999<-tree031.1999[,c(1, 2, 5:9)]

#2009
tree031.2009<-tree031wide[,c('tree','spec','dbh99','cond99', 'dbh09', 'cond09')]
tree031D.2009<-subset(tree031.2009, tree031.2009$cond99 %in% c("L", "M") & tree031.2009$cond09 %in% c("D", "G"))
tree031D.2009$cond09<-"M"
tree031L.2009<-subset(tree031.2009, tree031.2009$cond09 %in%c("L", "M") & !is.na(tree031.2009$cond99))
tree031L.2009$cond09<-"L"
tree031R.2009<-subset(tree031.2009, tree031.2009$cond09 %in%c("L", "M") & is.na(tree031.2009$cond99))
tree031R.2009$cond09<-"R"
tree031.2009<-rbind(tree031L.2009,tree031D.2009,tree031R.2009)
tree031.2009$year<-2009
tree031.2009$interval<-2009-1999
tree031.2009$dbhprior<-ifelse(tree031.2009$cond09=='R', 5, tree031.2009$dbh99)
tree031.2009<- rename(tree031.2009,c('spec'='species',"dbh09"="dbh", "cond09"="cond"))
tree031.2009<-tree031.2009[,c(1, 2, 5:9)]

#2014
tree031.2014<-tree031wide[,c('tree','spec','dbh09','cond09', 'dbh14', 'cond14')]
tree031D.2014<-subset(tree031.2014, tree031.2014$cond09 %in% c("L", "M") & tree031.2014$cond14 %in% c("D", "G"))
tree031D.2014$cond14<-"M"
tree031L.2014<-subset(tree031.2014, tree031.2014$cond14 %in%c("L", "M") & !is.na(tree031.2014$cond09))
tree031L.2014$cond14<-"L"
tree031R.2014<-subset(tree031.2014, tree031.2014$cond14 %in%c("L", "M") & is.na(tree031.2014$cond09))
tree031R.2014$cond14<-"R"
tree031.2014<-rbind(tree031L.2014,tree031D.2014,tree031R.2014)
tree031.2014$year<-2014
tree031.2014$interval<-2014-2009
tree031.2014$dbhprior<-ifelse(tree031.2014$cond14=='R', 5, tree031.2014$dbh09)
tree031.2014<- rename(tree031.2014,c('spec'='species',"dbh14"="dbh", "cond14"="cond"))
tree031.2014<-tree031.2014[,c(1, 2, 5:9)]

tree031<-rbind(tree031L.1990,tree031.1999,tree031.2009,tree031.2014)

tree031$doy<-NA
tree031$project<-"hemlock-mapped-tree-plot"
tree031$archive<-"hf031"
tree031$contact<-"barker-plotkin"
tree031$tract<-"PH"
tree031$site<-"hemlock woodlot"
tree031$type<-"conifer"
tree031$plot<-1
tree031$size<-7200
tree031$lat<-42.54
tree031$long<--72.18
tree031$obs.exp<-"obs"
tree031$treatment<-NA
tree031$treat.year<-NA
tree031$method<-"dbh"
tree031$min.dbh<-5
tree031$demography<-'yes'
tree031$subplot<-NA
tree031$subsize<-NA
tree031$year1<-tree031$year
tree031<-tree031[c('year', 'year1', 'doy', 'archive', 'contact', 'project','type', 'size', 'lat', 'long', 'obs.exp', 'treatment', 'treat.year', 'tract', 'site', 'plot', 'subplot', 'subsize', 'tree', 'species', 'dbh', 'method', 'min.dbh','interval', 'dbhprior', 'cond', 'demography')]

#HF032 LYFORD GRID
hf032_url<-getURL("http://harvardforest.fas.harvard.edu/sites/harvardforest.fas.harvard.edu/files/data/p03/hf032/hf032-01-tree.csv")
tree032wide<-read.csv(text=hf032_url)
#tree032wide<-read.csv("hf032-02-tree.csv")
summary(tree032wide)

#find missing measurements
missed75a<-subset(tree032wide, tree032wide$cond69 =='L' & is.na(tree032wide$dbh75) & tree032wide$cond75=='L' )
missed75b<-subset(tree032wide, tree032wide$cond69 =='L' & is.na(tree032wide$dbh75) & is.na(tree032wide$cond75))
missed75<-rbind(missed75a, missed75b)
missed91a<-subset(tree032wide, tree032wide$cond75 =='L' & is.na(tree032wide$dbh91) & tree032wide$cond01=='L')
missed91b<-subset(tree032wide, tree032wide$cond75 =='L' & is.na(tree032wide$dbh91) & is.na(tree032wide$cond91))
missed91<-rbind(missed91a, missed91b)
missed75and91<-subset(tree032wide, tree032wide$cond69 =='L' & is.na(tree032wide$dbh75) & is.na(tree032wide$dbh91) & tree032wide$cond01=='L')
missed01<-subset(tree032wide, tree032wide$cond91 =='L' & is.na(tree032wide$dbh01) & tree032wide$cond11=='L')
# here, we define missed trees in 1969 as those that are live in 1975 with a dbh >10cm. If dbh=<10cm, then we call it a 1975 recruit.
missed69<-subset(tree032wide, is.na(tree032wide$dbh69) & tree032wide$cond75=='L' & tree032wide$dbh75>10)
# nope. missed69b<-tree032wide$treeid %in% c(1301, 2787, 3310, 4661)
recruit75<-subset(tree032wide, is.na(tree032wide$dbh69) & tree032wide$cond75=='L' & tree032wide$dbh75<=10)


tree032.1969<-tree032wide[,c(1,3,6:7,9)]
tree032L.1969<-subset(tree032.1969, tree032.1969$cond69=="L" & !is.na(tree032.1969$dbh69))
tree032L.1969<- rename(tree032L.1969,c('treeid'='tree','block'='plot',"dbh69"="dbh"))
tree032L.1969$cond<-"L"
missed69<-missed69[,c(1,3,6:7,9)]
missed69<- rename(missed69,c('treeid'='tree','block'='plot',"dbh69"="dbh"))
missed69$cond<-"miss"
tree032.1969<-rbind(tree032L.1969,missed69)
tree032.1969$year<-1969
tree032.1969$interval<-NA
tree032.1969$dbhprior<-NA
tree032.1969<-tree032.1969[c('plot','tree', 'species', 'dbh','cond', 'year', 'interval', 'dbhprior')]

tree032.1975DL<-subset(tree032wide, tree032wide$cond69=="L"& tree032wide$cond75!="L" & tree032wide$cond91=='L')
tree032.1975L<-subset(tree032wide, tree032wide$cond69=="L"& tree032wide$cond75=="L"& !is.na(tree032wide$dbh75))
missed69<-subset(tree032wide, is.na(tree032wide$dbh69) & tree032wide$cond75=='L' & tree032wide$dbh75>10)
tree032.1975L<-rbind(tree032.1975L,missed69)
tree032.1975L$cond<-'L'
tree032.1975D<-subset(tree032wide, tree032wide$cond69=="L"& tree032wide$cond75!="L" & tree032wide$cond91!='L')
tree032.1975D$cond<-'M'
recruit75$cond<-'R'
missed75$cond<-'miss'
tree032.1975<-rbind(tree032.1975L,tree032.1975D, recruit75, missed75)
tree032.1975$year<-1975
tree032.1975$dbhprior<-ifelse(tree032.1975$cond=='R', 5, tree032.1975$dbh69)
tree032.1975<- rename(tree032.1975, c('treeid'='tree','block'='plot', 'dbh75'='dbh'))
tree032.1975$interval<-1975-1969
tree032.1975<-tree032.1975[,c('plot','tree', 'species', 'dbh','cond', 'year', 'interval', 'dbhprior')]

tree032.1991L<-subset(tree032wide, tree032wide$cond75=="L" & tree032wide$cond91=="L" & !is.na(tree032wide$dbh91)) #this includes missed75a
tree032.1991L$cond<-"L"
tree032.1991D<-subset(tree032wide, tree032wide$cond75=="L"& tree032wide$cond91!="L" & tree032wide$cond01!='L')
tree032.1991D<-rbind(tree032.1991D,missed75b)
tree032.1991D$cond<-"M"
tree032.1991R<-subset(tree032wide, is.na(tree032wide$dbh69)& is.na(tree032wide$dbh75) & !is.na(tree032wide$dbh91) & tree032wide$cond91=="L")
tree032.1991R$cond<-"R"
missed91$cond<-'miss'
tree032.1991<-rbind(tree032.1991L,tree032.1991D, tree032.1991R, missed91)
tree032.1991$year<-tree032.1991$meas3yr
tree032.1991$dbhprior<-ifelse(tree032.1991$cond=='R', 5, tree032.1991$dbh75)
tree032.1991<- rename(tree032.1991, c('treeid'='tree','block'='plot', 'dbh91'='dbh'))
tree032.1991$interval<-tree032.1991$year-1975
tree032.1991<-tree032.1991[,c('plot','tree', 'species', 'dbh','cond', 'year', 'interval', 'dbhprior')]

#somehow 20 trees extra in here
tree032.2001L<-subset(tree032wide, tree032wide$cond91=="L" & tree032wide$cond01=="L"& !is.na(tree032wide$dbh01)) #this includes missed91a
tree032.2001L$cond<-"L"
tree032.2001D<-subset(tree032wide, tree032wide$cond91=="L"& tree032wide$cond01!="L" & tree032wide$cond11!='L')
tree032.2001D<-rbind(tree032.2001D,missed91b)
tree032.2001D$cond<-"M"
tree032.2001R<-subset(tree032wide, is.na(tree032wide$dbh69)& is.na(tree032wide$dbh75) & is.na(tree032wide$dbh91) & !is.na(tree032wide$dbh01)& tree032wide$cond01=="L")
tree032.2001R$cond<-"R"
tree032.2001<-rbind(tree032.2001L,tree032.2001D, tree032.2001R)
tree032.2001$year<-2001
tree032.2001$interval<-2001-tree032.2001$meas3yr
tree032.2001$dbhprior<-ifelse(tree032.2001$cond=='R', 5, tree032.2001$dbh91)
tree032.2001<- rename(tree032.2001, c('treeid'='tree','block'='plot', 'dbh01'='dbh'))
tree032.2001<-tree032.2001[,c('plot','tree', 'species', 'dbh','cond', 'year', 'interval', 'dbhprior')]


tree032.2011L<-subset(tree032wide, tree032wide$cond01=="L" & tree032wide$cond11=="L"& !is.na(tree032wide$dbh11)) 
tree032.2011L$cond<-"L"
tree032.2011D<-subset(tree032wide, tree032wide$cond01=="L"& tree032wide$cond11!="L")
tree032.2011D$cond<-"M"
tree032.2011R<-subset(tree032wide, is.na(tree032wide$dbh75)& is.na(tree032wide$dbh91) & is.na(tree032wide$dbh01) & !is.na(tree032wide$dbh11)& tree032wide$cond11=="L")
tree032.2011R$cond<-"R"
tree032.2011<-rbind(tree032.2011L,tree032.2011D, tree032.2011R)
tree032.2011$year<-2011
tree032.2011$interval<-2011-2001
tree032.2011$dbhprior<-ifelse(tree032.2011$cond=='R', 5, tree032.2011$dbh01)
tree032.2011<- rename(tree032.2011, c('treeid'='tree','block'='plot', 'dbh11'='dbh'))
tree032.2011<-tree032.2011[,c('plot','tree', 'species', 'dbh','cond', 'year', 'interval', 'dbhprior')]

tree032<-rbind(tree032.1969, tree032.1975, tree032.1991, tree032.2001, tree032.2011)
remove032 <- which(tree032$species=="AMSP") #Amelanchier is not considered a tree species
tree032 <- tree032[-remove032,] 
tree032$dbh<-as.numeric(tree032$dbh)
tree032$doy<-NA
tree032$project<-"lyford-grid"
tree032$archive<-"hf032"
tree032$contact<-"barker-plotkin"
tree032$tract<-"PH"
tree032$site<-"lyford"
tree032$type<-"hardwood"
tree032$subplot<-tree032$plot
tree032$subsize<-ifelse(tree032$subplot=="SW01",262.3,929.03) #BLOCK SW01 is only 262.3 m2. ABP 1/21/2015.
tree032$plot<-'lyford'
tree032$size<-28800
tree032$lat<-42.53
tree032$long<--72.18
tree032$obs.exp<-"obs"
tree032$treatment<-NA
tree032$treat.year<-NA
tree032$method<-"dbh"
tree032$notes<-NA
tree032$demography<-'yes'
tree032$year1<-ifelse(tree032$year %in% c(1987, 1991, 1992), 1991, tree032$year)
tree032$min.dbh<-5
tree032<-tree032[c('year', 'year1','doy', 'archive', 'contact', 'project','type', 'size', 'lat', 'long', 'obs.exp', 'treatment', 'treat.year', 'tract', 'site', 'plot', 'subplot', 'subsize', 'tree', 'species', 'dbh', 'method', 'min.dbh', 'interval', 'dbhprior', 'cond', 'demography')]

#HF036 Mapped Overstory Plots
hf036_url<-getURL("http://harvardforest.fas.harvard.edu/sites/harvardforest.fas.harvard.edu/files/data/p03/hf036/hf036-01-tree.csv")
tree036wide<-read.csv(text=hf036_url)
#are there live trees missing a measurement?
miss900313<-subset(tree036wide, tree036wide$COND90!='D' & is.na(tree036wide$DBH03) & tree036wide$COND13!='D')
#Nope!

#1990. Need only the live subset.
tree036L.1990<-subset(tree036wide, tree036wide$cond90 %in% c("L", "M"))
tree036L.1990$cond90<-"L"
tree036L.1990$year<-1990
tree036L.1990$interval<-NA
tree036L.1990$dbhprior<-NA
tree036L.1990<- rename(tree036L.1990,c("dbh90"="dbh", "cond90"="cond"))
tree036.1990<-tree036L.1990[,c('plot','tree', 'species', 'dbh','cond', 'year', 'interval', 'dbhprior')]

#2003. Need: 1) growth (live 90 & 03); 2) recruits; 3) mortality (live 90 & dead 03)
tree036D.2003<-subset(tree036wide, tree036wide$cond90 %in% c("L", "M") & tree036wide$cond03 %in% c("D", "G"))
tree036D.2003$cond03<-"M"
tree036L.2003<-subset(tree036wide, tree036wide$cond03 %in%c("L", "M") & !is.na(tree036wide$cond90))
tree036L.2003$cond03<-"L"
tree036R.2003<-subset(tree036wide, tree036wide$cond03 %in%c("L", "M") & is.na(tree036wide$cond90))
tree036R.2003$cond03<-"R"
tree036.2003<-rbind(tree036L.2003,tree036D.2003,tree036R.2003)
tree036.2003$year<-2003
tree036.2003$interval<-2003-1990
tree036.2003$dbhprior<-ifelse(tree036.2003$cond03=='R', 5, tree036.2003$dbh90)
tree036.2003<- rename(tree036.2003,c("dbh03"="dbh", "cond03"="cond"))
tree036.2003<-tree036.2003[,c('plot','tree', 'species', 'dbh','cond', 'year', 'interval', 'dbhprior')]

#2013. Need: 1) growth (live 13 & 03); 2) recruits; 3) mortality (live 03 & dead 13)
tree036D.2013<-subset(tree036wide, tree036wide$cond03 %in% c("L", "M") & tree036wide$cond2013 %in% c("D", "G"))
tree036D.2013$cond2013<-"M"
tree036L.2013<-subset(tree036wide, tree036wide$cond2013 %in%c("L", "M") & !is.na(tree036wide$cond03))
tree036L.2013$cond2013<-"L"
tree036R.2013<-subset(tree036wide, tree036wide$cond2013 %in%c("L", "M") & is.na(tree036wide$cond03))
tree036R.2013$cond2013<-"R"
tree036.2013<-rbind(tree036L.2013,tree036D.2013,tree036R.2013)
tree036.2013$year<-2013
tree036.2013$interval<-2013-2003
tree036.2013$dbhprior<-ifelse(tree036.2013$cond2013=='R', 5, tree036.2013$dbh03)
tree036.2013<- rename(tree036.2013,c("dbh2013"="dbh", "cond2013"="cond"))
tree036.2013<-tree036.2013[,c('plot','tree', 'species', 'dbh','cond', 'year', 'interval', 'dbhprior')]

tree036<-rbind(tree036.1990,tree036.2003,tree036.2013)

tree036$doy<-NA
tree036$project<-"mapped-tree-plot"
tree036$archive<-"hf036"
tree036$contact<-"barker-plotkin"
tree036$tract<-"TS"
tree036$site<-"TS"
tree036$type<-"hardwood"
tree036$size<-2500
tree036$lat<-42.5
tree036$long<--72.2
tree036$obs.exp<-"obs"
tree036$treatment<-NA
tree036$treat.year<-NA
tree036$method<-"dbh"
tree036$min.dbh<-5
tree036$demography<-'yes'
tree036$subplot<-NA
tree036$subsize<-NA
tree036$year1<-tree036$year
tree036<-tree036[c('year', 'year1','doy', 'archive', 'contact', 'project','type', 'size', 'lat', 'long', 'obs.exp', 'treatment', 'treat.year', 'tract', 'site', 'plot', 'subplot', 'subsize', 'tree', 'species', 'dbh', 'method','min.dbh', 'interval', 'dbhprior', 'cond', 'demography')]


#HF053 Hemlock History. Get better lat/long for each plot.
#hf053_url<-getURL("http://harvardforest.fas.harvard.edu/sites/harvardforest.fas.harvard.edu/files/data/p05/hf053/hf053-01-trees.csv")
#tree053wide<-read.csv(text=hf053_url)

#This data set makes it hard to figure out what is dead in the 1995 census. 2002 & 2012 are fine (vigor= 5 is dead). 
#So, use this version w/ a cond95 column added by ABP, 4/17/2015.
tree053wide<-read.csv("hf053-01-trees_cond.csv")
str(tree053wide)
summary(tree053wide)

#1995. Need only the live & missed subsets.
tree053.1995<-subset(tree053wide, tree053wide$cond95 !='D')
tree053.1995$year<-1995
tree053.1995$dbh<-tree053.1995$dbh95
tree053.1995$cond<-tree053.1995$cond95
tree053.1995$interval<-NA
tree053.1995$dbhprior<-NA
tree053.1995<-tree053.1995[,c('plot','tree', 'species', 'dbh','cond', 'year', 'interval', 'dbhprior')]

#2002. Need: 1) growth (live 90 & 03); 2) mortality NO RECRUITMENT
tree053D.2002<-subset(tree053wide, tree053wide$cond95 %in% c("L", "miss") & tree053wide$vigor02 ==5)
tree053D.2002$cond<-"M"
tree053L.2002<-subset(tree053wide, tree053wide$cond95 %in%c("L", "miss") & tree053wide$vigor02 !=5)
tree053L.2002$cond<-"L"
tree053.2002<-rbind(tree053L.2002,tree053D.2002)
tree053.2002$year<-2002
tree053.2002$interval<-2002-1995
tree053.2002$dbhprior<-tree053.2002$dbh95
tree053.2002$dbh<-tree053.2002$dbh02
tree053.2002<-tree053.2002[,c('plot','tree', 'species', 'dbh','cond', 'year', 'interval', 'dbhprior')]

#2012. Need: 1) growth (live 90 & 03); 2) mortality NO RECRUITMENT
tree053D.2012<-subset(tree053wide, tree053wide$vigor02 !=5 & tree053wide$vigor12 ==5)
tree053D.2012$cond<-"M"
tree053L.2012<-subset(tree053wide, tree053wide$vigor02 !=5 & tree053wide$vigor12 !=5)
tree053L.2012$cond<-"L"
tree053miss.2012<-subset(tree053wide, tree053wide$vigor02 !=5 & is.na(tree053wide$vigor12))
tree053miss.2012$cond<-"miss"
tree053.2012<-rbind(tree053L.2012,tree053D.2012, tree053miss.2012)
tree053.2012$year<-2012
tree053.2012$interval<-2012-2002
tree053.2012$dbhprior<-tree053.2012$dbh02
tree053.2012$dbh<-tree053.2012$dbh12
tree053.2012<-tree053.2012[,c('plot','tree', 'species', 'dbh','cond', 'year', 'interval', 'dbhprior')]

tree053<-rbind(tree053.1995,tree053.2002,tree053.2012)

tree053$doy<-NA
tree053$project<-"hemlock history"
tree053$archive<-"hf053"
tree053$contact<-"barker-plotkin"
tree053$tract<-ifelse(substr(tree053$plot,1,2)=="PH","PH","SC")
tree053$site<-ifelse(tree053$plot=="PH2","PH comp 2",ifelse(tree053$plot=="PH7","PH comp 7",ifelse(tree053$plot=="SC10","SC comp 10","SC comp 9")))
tree053$type<-"conifer"
tree053$size<-30^2
tree053$lat<-ifelse(tree053$plot == 'PH2', 42.54, ifelse(tree053$plot=='PH7', 42.541, ifelse(tree053$plot=='SC9', 42.456, 42.453)))
tree053$long<-ifelse(tree053$plot == 'PH2', -72.179, ifelse(tree053$plot=='PH7', -72.175, ifelse(tree053$plot=='SC9', -72.166, -72.168)))
tree053$obs.exp<-"obs"
tree053$treatment<-NA
tree053$treat.year<-NA
tree053$method<-"dbh"
tree053$demography<-'yes'
tree053$subplot<-NA
tree053$subsize<-NA
tree053$year1<-tree053$year
tree053$min.dbh<-2.5
tree053<-tree053[c('year', 'year1','doy', 'archive', 'contact', 'project','type', 'size', 'lat', 'long', 'obs.exp', 'treatment', 'treat.year', 'tract', 'site', 'plot', 'subplot', 'subsize', 'tree', 'species', 'dbh', 'method','min.dbh', 'interval', 'dbhprior', 'cond', 'demography')]

#HF126. Hemlock Removal Experiment
hf126_url<-getURL("http://harvardforest.fas.harvard.edu/sites/harvardforest.fas.harvard.edu/files/data/p12/hf126/hf126-02-tree.csv")
tree126wide<-read.csv(text=hf126_url)
#tree126w<-read.csv("hf126-02-tree_final_P7censored.csv")    

#2004 (T0). Need only the live subset, and the one missed tree.
tree126L.2004<-subset(tree126wide, tree126wide$condt0=='L')
tree126L.2004$cond<-ifelse(is.na(tree126L.2004$dbht0), 'miss', 'L')
tree126L.2004$cond<-as.factor(tree126L.2004$cond)
tree126L.2004$year<-tree126L.2004$yeart0
tree126L.2004$interval<-NA
tree126L.2004$dbhprior<-NA
tree126L.2004<- rename(tree126L.2004,c("dbht0"="dbh"))
tree126.2004<-tree126L.2004[,c('plot','tree', 'species', 'dbh','cond', 'year', 'interval', 'dbhprior')]

#2009. Need: 1) growth ; 2) recruits; 3) mortality ; and one missed stem in 09 (L, DBH=NA)
tree126D.2009<-subset(tree126wide, tree126wide$condt0=='L' & tree126wide$cond09=="D")
tree126D.2009$cond<-"M"
tree126L.2009<-subset(tree126wide, tree126wide$cond09 %in% c("l","L") & tree126wide$condt0 =="L")
tree126L.2009$cond<-ifelse(is.na(tree126L.2009$dbh09), 'miss', 'L')
tree126R.2009<-subset(tree126wide, tree126wide$cond09 =="L"& is.na(tree126wide$condt0))
tree126R.2009$cond<-"R"
tree126.2009<-rbind(tree126L.2009,tree126D.2009,tree126R.2009)
tree126.2009$cond<-as.factor(tree126.2009$cond)
tree126.2009$year<-2009
tree126.2009$interval<-2009-tree126.2009$yeart0
tree126.2009$dbhprior<-ifelse(tree126.2009$cond=='R', 5, tree126.2009$dbht0)
tree126.2009<- rename(tree126.2009,c("dbh09"="dbh"))
tree126.2009<-tree126.2009[,c('plot','tree', 'species', 'dbh','cond', 'year', 'interval', 'dbhprior')]

#2014. There will be a bunch of missed trees because of the discontinued trees in plot7.
tree126D.2014<-subset(tree126wide, tree126wide$cond09 %in% c("l","L")  & tree126wide$cond14=="D")
tree126D.2014$cond<-"M"
tree126L.2014<-subset(tree126wide, tree126wide$cond09 %in% c("l","L") & tree126wide$cond14 =="L")
tree126L.2014$cond<-'L'
tree126miss.2014<-subset(tree126wide, tree126wide$cond09 %in% c("l","L") & is.na(tree126wide$cond14))
tree126miss.2014$cond<- 'miss'
tree126R.2014<-subset(tree126wide, tree126wide$cond14 =="L"& is.na(tree126wide$cond09))
tree126R.2014$cond<-"R"
tree126.2014<-rbind(tree126L.2014,tree126D.2014,tree126R.2014, tree126miss.2014)
tree126.2014$cond<-as.factor(tree126.2014$cond)
tree126.2014$year<-2014
tree126.2014$interval<-2014-2009
tree126.2014$dbhprior<-ifelse(tree126.2014$cond=='R', 5, tree126.2014$dbh09)
tree126.2014<- rename(tree126.2014,c("dbh14"="dbh"))
tree126.2014<-tree126.2014[,c('plot','tree', 'species', 'dbh','cond', 'year', 'interval', 'dbhprior')]

tree126<-rbind(tree126.2004,tree126.2009,tree126.2014)

tree126$doy<-NA
tree126$project<-"hf-here"
tree126$archive<-"hf126"
tree126$contact<-"barker-plotkin"
tree126$tract<-"SIMES"
tree126$site<-"simes"
tree126$type<-as.factor(ifelse(tree126$plot %in% c(7,8),"hardwood",ifelse(tree126$year==2014 & tree126$plot %in% c(1,2,4,5),"hardwood","conifer")))
tree126$size<-ifelse(tree126$plot %in% c(1,3),90*85,ifelse(tree126$plot==2,85^2,ifelse(tree126$plot==7 & tree126$year==2014, 6000, 90^2)))
tree126$lat<-42.475
tree126$long<--72.215
tree126$obs.exp<-as.factor(ifelse(tree126$plot %in% c(3,6,7,8),"obs","exp"))
tree126$treatment<-revalue(as.factor(tree126$plot),c("1"="girdled","2"="logged","3"="hemlock control","4"="logged","5"="girdled","6"="hemlock control","7"="hardwood control","8"="hardwood control"))
tree126$treat.year<-ifelse(tree126$plot %in% c(3,6,7,8),NA,2005)
tree126$method<-as.factor("dbh")
tree126$demography<-'yes'
tree126$subplot<-NA
tree126$subsize<-NA
tree126$year1<-ifelse(tree126$year %in% c(2003, 2004, 2005, 2006), 2004, tree126$year)
tree126$min.dbh<-5
tree126<-tree126[c('year', 'year1','doy', 'archive', 'contact', 'project','type', 'size', 'lat', 'long', 'obs.exp', 'treatment', 'treat.year', 'tract', 'site', 'plot', 'subplot', 'subsize', 'tree', 'species', 'dbh', 'method','min.dbh', 'interval', 'dbhprior', 'cond', 'demography')]
# write.table(tree126, "hf126liveCen.csv", sep = ",", row.names = FALSE)

#HF008
#The data from the archive need some work.

#Changes from live-trees.
# All trees above 5cm Diameter Breast Height (DBH) were numbered and measured in 1988. In subsequent years, trees previously too small were tagged and measured. In this dataset, we report tree-level DBH measurements. 
# Tree data is reported by subplot - numbered [a-f][[1-6], for a total of 36 5x5m subplots per plot. 
#Note that in some years, some subplots were not sampled (HC-F1, PL-F[1-6]). This is important when scaling tree-level DBH to biomass per unit area. 
# Also note that DBH is listed as 0 for trees not yet large enough for the inventory. DBH is also listed as 0 after the death of a tree.

#How about do this:
#plot is each 5x5. rename these so they have the whole plot name too. sum up by whole plot & year to get size.? 
#But not clear how you know what wasn't sampled. A 0 listing for a tree can mean: a) not yet recruited; b) died; c) not sampled.

hf008_url<-getURL("http://harvardforest.fas.harvard.edu/sites/harvardforest.fas.harvard.edu/files/data/p00/hf008/hf008-04-tree.csv")
tree008wide<-read.csv(text=hf008_url)
#First, some fixer-uppers here
tree008wide$plot<-revalue(tree008wide$plot, c("PNS "="PNS", 'PL '='PL', 'PC '='PC', 'PH '='PH'))
tree008wide$species<-revalue(tree008wide$species,c("ACSA3 "="ACSA","PRSE2 "="PRSE","PRSE2"="PRSE", "ACPE "="ACPE","ACRU "="ACRU","BELE "="BELE" ,"FAGR "="FAGR","NYSY "="NYSY", "PIRE "="PIRE","PIST "="PIST","QUVU "="QUVE","TSCA "="TSCA"))
levels(tree008wide$species) <- c(levels(tree008wide$species), "UNK")
tree008wide$species[is.na(tree008wide$species)] <- 'UNK'
levels(tree008wide$plot)

#here, try to figure out which 5x5 subplot x year combinations not sampled.
subplot<-ddply(tree008wide, 
                c("plot","subplot"),
                summarise,
                d.1988=sum(dbh.10.1988),
               d.1990=sum(dbh.11.1990),  
               d.1993=sum(dbh.11.1993), 
               d.1997=sum(dbh.2.1997), 
               d.2000=sum(dbh.03.2000), 
               d.2003=sum(dbh.04.2003), 
               d.2006=sum(dbh.04.2006), 
              d.2008= sum(dbh.10.2008),
              d.2013=sum(dbh.10.2013))

notmeas<-subset(subplot,d.1993==0)
#So, I think it is HC F1 not measured 1988, 1990 and 1993. So plot size in those years is 900-25 = 875m2.
#And, PL F1-F6, 1988 only. So plot size in that year is 900 - (6*25) = 750m2.

tree008.0<-subset(tree008wide, tree008wide$dbh.10.1988==0)

#initial census - pull out live (dbh>0) only
tree008L.1988<-subset(tree008wide, tree008wide$dbh.10.1988>0)
tree008L.1988<- rename(tree008L.1988,c('treetag'='tree',"dbh.10.1988"="dbh"))
tree008L.1988$cond<-"L"
tree008Miss.1988<-subset(tree008wide, tree008wide$dbh.10.1988==0 & tree008wide$subplot=='E6 ' & tree008wide$dbh.11.1990>0)
tree008Miss.1988<- rename(tree008Miss.1988,c('treetag'='tree',"dbh.10.1988"="dbh"))
tree008Miss.1988$cond<-'miss'
set1988<-rbind(tree008L.1988, tree008Miss.1988)
set1988$year<-1988
set1988$interval<-NA
set1988$dbhprior<-NA
set1988<-set1988[c('plot', 'subplot', 'tree', 'species', 'dbh','cond', 'year', 'interval', 'dbhprior')]

#subseqent 7 censuses: pull out trio of measurements - prior, now, next
##1990##
set<-tree008wide[,c(1:4,5, 6, 7)]
names(set)[5]<-"prior"
names(set)[6]<-"now"
names(set)[7]<-"Next"
#then run this and rename each year to keep output?
setL<-subset(set, set$prior>0 & set$now>0)
setL$cond<-'L'
setD<-subset(set, set$prior>0 & set$now==0 & set$Next==0)
setD$cond<-'M'
setR<-subset(set, set$prior==0 & set$now>0)
#this one is special for 1990
setR$cond<-ifelse(setR$subplot=='E6 ', 'R', 'L')

setMiss<-subset(set, set$prior>0 & set$now==0 & set$Next>0)
setMiss$cond<-'miss'
set.combo<-rbind(setL, setD, setR, setMiss)
#customize
set1990<-set.combo
set1990$year<-1990
set1990<- rename(set1990, c('treetag'='tree', 'prior'='dbhprior', 'now'='dbh'))
set1990$interval<-1990-1988
set1990<-set1990[c('plot','subplot','tree', 'species', 'dbh','cond', 'year', 'interval', 'dbhprior')]

##1993##
set<-tree008wide[,c(1:4,6, 7, 8)]
names(set)[5]<-"prior"
names(set)[6]<-"now"
names(set)[7]<-"Next"
#then run this and rename each year to keep output?
setL<-subset(set, set$prior>0 & set$now>0)
setL$cond<-'L'
setD<-subset(set, set$prior>0 & set$now==0 & set$Next==0)
setD$cond<-'M'
setR<-subset(set, set$prior==0 & set$now>0)
setR$cond<-'R'
setMiss<-subset(set, set$prior>0 & set$now==0 & set$Next>0)
setMiss$cond<-'miss'
set.combo<-rbind(setL, setD, setR, setMiss)
set.combo$prior<-ifelse(set.combo$cond=='R', 5, set.combo$prior)

#customize
set1993<-set.combo
set1993$year<-1993
set1993<- rename(set1993, c('treetag'='tree', 'prior'='dbhprior', 'now'='dbh'))
set1993$interval<-1993-1990
set1993<-set1993[c('plot','subplot','tree', 'species', 'dbh','cond', 'year', 'interval', 'dbhprior')]

##1996##
set<-tree008wide[,c(1:4,7, 8, 9)]
names(set)[5]<-"prior"
names(set)[6]<-"now"
names(set)[7]<-"Next"
#then run this and rename each year to keep output?
setL<-subset(set, set$prior>0 & set$now>0)
setL$cond<-'L'
setD<-subset(set, set$prior>0 & set$now==0 & set$Next==0)
setD$cond<-'M'
setR<-subset(set, set$prior==0 & set$now>0)
setR$cond<-ifelse(setR$plot=='HC' & setR$subplot=='F1', 'L', 'R')
setMiss<-subset(set, set$prior>0 & set$now==0 & set$Next>0)
setMiss$cond<-'miss'
set.combo<-rbind(setL, setD, setR, setMiss)
set.combo$prior<-ifelse(set.combo$cond=='R', 5, set.combo$prior)

#customize
set1996<-set.combo
set1996$year<-1996
set1996<- rename(set1996, c('treetag'='tree', 'prior'='dbhprior', 'now'='dbh'))
set1996$interval<-1996-1993
set1996<-set1996[c('plot','subplot','tree', 'species', 'dbh','cond', 'year', 'interval', 'dbhprior')]

##1999##
set<-tree008wide[,c(1:4,8, 9, 10)]
names(set)[5]<-"prior"
names(set)[6]<-"now"
names(set)[7]<-"Next"
#then run this and rename each year to keep output?
setL<-subset(set, set$prior>0 & set$now>0)
setL$cond<-'L'
setD<-subset(set, set$prior>0 & set$now==0 & set$Next==0)
setD$cond<-'M'
setR<-subset(set, set$prior==0 & set$now>0)
setR$cond<-'R'
setMiss<-subset(set, set$prior>0 & set$now==0 & set$Next>0)
setMiss$cond<-'miss'
set.combo<-rbind(setL, setD, setR, setMiss)
set.combo$prior<-ifelse(set.combo$cond=='R', 5, set.combo$prior)

#customize
set1999<-set.combo
set1999$year<-1999
set1999<- rename(set1999, c('treetag'='tree', 'prior'='dbhprior', 'now'='dbh'))
set1999$interval<-1999-1996
set1999<-set1999[c('plot','subplot','tree', 'species', 'dbh','cond', 'year', 'interval', 'dbhprior')]

##2002##
set<-tree008wide[,c(1:4,9, 10, 11)]
names(set)[5]<-"prior"
names(set)[6]<-"now"
names(set)[7]<-"Next"
#then run this and rename each year to keep output?
setL<-subset(set, set$prior>0 & set$now>0)
setL$cond<-'L'
setD<-subset(set, set$prior>0 & set$now==0 & set$Next==0)
setD$cond<-'M'
setR<-subset(set, set$prior==0 & set$now>0)
setR$cond<-'R'
setMiss<-subset(set, set$prior>0 & set$now==0 & set$Next>0)
setMiss$cond<-'miss'
set.combo<-rbind(setL, setD, setR, setMiss)
set.combo$prior<-ifelse(set.combo$cond=='R', 5, set.combo$prior)

#customize
set2002<-set.combo
set2002$year<-2002
set2002<- rename(set2002, c('treetag'='tree', 'prior'='dbhprior', 'now'='dbh'))
set2002$interval<-2002-1999
set2002<-set2002[c('plot','subplot','tree', 'species', 'dbh','cond', 'year', 'interval', 'dbhprior')]

##2005##
set<-tree008wide[,c(1:4,10, 11, 12)]
names(set)[5]<-"prior"
names(set)[6]<-"now"
names(set)[7]<-"Next"
#then run this and rename each year to keep output?
setL<-subset(set, set$prior>0 & set$now>0)
setL$cond<-'L'
setD<-subset(set, set$prior>0 & set$now==0 & set$Next==0)
setD$cond<-'M'
setR<-subset(set, set$prior==0 & set$now>0)
setR$cond<-'R'
setMiss<-subset(set, set$prior>0 & set$now==0 & set$Next>0)
setMiss$cond<-'miss'
set.combo<-rbind(setL, setD, setR, setMiss)
set.combo$prior<-ifelse(set.combo$cond=='R', 5, set.combo$prior)

#customize
set2005<-set.combo
set2005$year<-2005
set2005<- rename(set2005, c('treetag'='tree', 'prior'='dbhprior', 'now'='dbh'))
set2005$interval<-2005-2002
set2005<-set2005[c('plot','subplot','tree', 'species', 'dbh','cond', 'year', 'interval', 'dbhprior')]

##2008##
set<-tree008wide[,c(1:4, 11, 12, 13)]
names(set)[5]<-"prior"
names(set)[6]<-"now"
names(set)[7]<-"Next"
#then run this and rename each year to keep output?
setL<-subset(set, set$prior>0 & set$now>0)
setL$cond<-'L'
setD<-subset(set, set$prior>0 & set$now==0& set$Next==0)
setD$cond<-'M'
setR<-subset(set, set$prior==0 & set$now>0)
setR$cond<-'R'
setMiss<-subset(set, set$prior>0 & set$now==0 & set$Next>0)
setMiss$cond<-'miss'
set.combo<-rbind(setL, setD, setR, setMiss)
set.combo$prior<-ifelse(set.combo$cond=='R', 5, set.combo$prior)

#customize
set2008<-set.combo
set2008$year<-2008
set2008<- rename(set2008, c('treetag'='tree', 'prior'='dbhprior', 'now'='dbh'))
set2008$interval<-2008-2005
set2008<-set2008[c('plot','subplot','tree', 'species', 'dbh','cond', 'year', 'interval', 'dbhprior')]

##2013 - HARDWOOD PLOTS ONLY MEASURED!!!##
set<-tree008wide[,c(1:4, 12, 13)]
names(set)[5]<-"prior"
names(set)[6]<-"now"
#then run this and rename each year to keep output?
setL<-subset(set, set$prior>0 & set$now>0)
setL$cond<-'L'
setD<-subset(set, set$prior>0 & set$now==0)
setD$cond<-'M'
setR<-subset(set, set$prior==0 & set$now>0)
setR$cond<-'R'
set.combo<-rbind(setL, setD, setR)
set.combo$prior<-ifelse(set.combo$cond=='R', 5, set.combo$prior)

#customize
set2013<-set.combo
set2013$year<-2013
set2013<- rename(set2013, c('treetag'='tree', 'prior'='dbhprior', 'now'='dbh'))
set2013$interval<-2013-2008
set2013<-set2013[c('plot','subplot','tree', 'species', 'dbh','cond', 'year', 'interval', 'dbhprior')]

tree008<-rbind(set1988, set1990, set1993, set1996, set1999, set2002, set2005, set2008, set2013)
tree008$subsize<-5^2
tree008$size<-ifelse (tree008$plot=='HC' & tree008$year==1988, 875, ifelse(tree008$plot=='PL' & tree008$year %in% c(1988, 1990, 1993), 750, 900))
tree008$doy<-NA
tree008$project<-"chronicN"
tree008$archive<-"hf008"
tree008$contact<-"frey"
tree008$tract<-"PH"
tree008$obs.exp<-ifelse((tree008$plot=="PC")&(tree008$plot=="HC"),"obs","exp")
tree008$type<-substr(tree008$plot,1,1)
tree008$type<-revalue(tree008$type, c("P"="conifer","H"="hardwood"))
tree008$site<-ifelse(tree008$type=="conifer","red pine plantation","mixed hardwood")
tree008$obs.exp<-substr(tree008$plot,2,2)
tree008$obs.exp<-revalue(tree008$obs.exp, c("C"="obs","H"="exp","N"="exp","L"="exp"))
tree008$treatment<-ifelse(tree008$plot %in% c('HL', 'PL', 'HNS','PNS'), '50', ifelse(tree008$plot %in% c('HH', 'PH'), '150','NA'))
tree008$treat.year<-ifelse (tree008$plot %in% c('HL','HNS','HH'), '1988-ongoing', ifelse (tree008$obs.exp=="obs","NA", ifelse (tree008$plot=='PH', '1988-2005', '1988-2009')))
tree008$notes<-NA
tree008$lat<-42.54
tree008$long<--72.18
tree008$method<-"dbh"
tree008$demography<-'yes'
tree008$min.dbh<-5
tree008$year1<-tree008$year
tree008<-tree008[c('year', 'year1','doy', 'archive', 'contact', 'project','type', 'size', 'lat', 'long', 'obs.exp', 'treatment', 'treat.year', 'tract', 'site', 'plot', 'subplot', 'subsize', 'tree', 'species', 'dbh', 'method', 'min.dbh', 'interval', 'dbhprior', 'cond', 'demography')]



#HF162. Plantation biodiversity. Trees NOT individually tracked.
tree162<-read.csv("file:///C:/Users/aabarker/Dropbox/HF C Synthesis/Data/live trees/live tree data & code/hf162-02-trees17.csv")
summary(tree162)

tree162<-subset(tree162,!is.na(tree162$year) & !is.na(tree162$species))
tree162$doy<-NA
tree162$project<-"p.biodiv"
tree162$archive<-"hf162"
tree162$contact<-"barker-plotkin"
tree162$type<-"conifer"
tree162$tree<-NA
tree162$size<-20^2

tree162plots<-read.csv("hf162-01-plots.csv")
head(tree162plots)
tree162plots$tract<-substr(tree162plots$Name,1,2)
tree162plots$treatment<-ifelse(tree162plots$Treat=="Harvest","harvest",NA)
tree162plots$obs.exp<-ifelse(tree162plots$Treat=="Harvest","exp","obs")
tree162plots$treat.year<-substr(tree162plots$HarvDate,1,4)
tree162plots<- rename(tree162plots,c('Plot'='plot',"Comp"="site"))
tree162plots<-tree162plots[,c(1,8,14:15,19:22)]

tree162<-merge(tree162,tree162plots,by="plot")
tree162$method<-"dbh"
tree162$interval<-NA
tree162$dbhprior<-NA
tree162$cond<-'L'
tree162$demography<-'no'
tree162$subplot<-NA
tree162$subsize<-NA
tree162$year1<-tree162$year
tree162$min.dbh<-2.5
tree162<-tree162[c('year', 'year1','doy', 'archive', 'contact', 'project','type', 'size', 'lat', 'long', 'obs.exp', 'treatment', 'treat.year', 'tract', 'site', 'plot', 'subplot', 'subsize', 'tree', 'species', 'dbh', 'method', 'min.dbh', 'interval', 'dbhprior', 'cond', 'demography')]


#HF175. Ally Dunn

tree175<-read.csv("hf175-01-DBH-cond.csv")

###########WORK ON THIS MORE TO GET Mort & Recruit IN THIS##############
# mort.ind<-tree175$dbh=="RIP"
# mort.ind[is.na(mort.ind)]<-F
# 
# dups<-duplicated(tree175[mort.ind,c("tree","dbh")])
# dups[is.na(dups)]<-F
# summary(live)
# 
# live<-subset(tree175, tree175$cond %in% c('L', 'miss', 'R'))
# summary(live)
# #add cond here
# mort<-tree175[mort.ind,][!dups,]
# mort$dbh<-revalue(mort$dbh, c("RIP"="NA"))
# #add cond here
# tree175<-rbind(live,mort)
tree175$dbh<-(as.numeric(as.character(tree175$dbh)))
summary(tree175)

tree175$year<-substr(tree175$date,1,4)
tree175$year<-as.factor(tree175$year)
str(tree175)
#keep only one 2010 measurement. Use "2010.09.01" unless it is NA, then use "2010.06.01"
tree175<-ddply(tree175,c("year","plot","treatment","tree","species","cond", 'notes'),summarise,dbh=max(dbh))
#some parts of the code below didn't seem to work. Treatment was listed as '2' rather than 'harvest' and treat.year was NA throughout. 
#ABP corrected in the .csv live tree compilation directly, Jan 2015.

#When scaling up to site level, keep in mind that H90D has 0 trees in it.

tree175<-subset(tree175, tree175$dbh!="RIP" & !is.na(tree175$dbh))
tree175$doy<-NA
tree175$project<-"hf.regen"
tree175$archive<-"hf175"
tree175$contact<-"dunn"
tree175$tract<-"PH"
tree175$site<-ifelse(tree175$treatment=="control","red pine plantation","red pine plantation harvest")
tree175$type<-ifelse(tree175$treatment=="control","conifer","hardwood")
tree175$size<-314.1593
tree175$lat<-42.53
tree175$long<--72.19
tree175$obs.exp<-ifelse(tree175$treatment=="harvest","exp","obs")
tree175$treatment<-ifelse(tree175$treatment=="harvest",tree175$treatment,NA)
tree175$treat.year<-ifelse(tree175$treatment=="harvest",1990,NA)
tree175$species<-revalue(tree175$species, c("ae"="ULAM", "b"="FAGR", "bb"="BELE","bc"="PRSE","bf"="ABBA","gb"="BEPO", "h"="TSCA","pb"="BEPA","rm"="ACRU","ro"="QURU","rp"="PIRE","sm"="ACSA","wa"="FRAM","wp"="PIST","ws"="PIGL" ,"yb"="BEAL", "sp?"="UNK"))
tree175$dbh<-(as.numeric(as.character(tree175$dbh)))
tree175$method<-"dbh"
tree175$interval<-NA
tree175$dbhprior<-NA
tree175$cond<-'L'
tree175$demography<-'no'
tree175$subplot<-NA
tree175$subsize<-NA
tree175$year1<-tree175$year
tree175$min.dbh<- 5
tree175<-tree175[c('year', 'year1','doy', 'archive', 'contact', 'project','type', 'size', 'lat', 'long', 'obs.exp', 'treatment', 'treat.year', 'tract', 'site', 'plot', 'subplot', 'subsize', 'tree', 'species', 'dbh', 'method','min.dbh','interval', 'dbhprior', 'cond', 'demography')]

#levels(tree175$species) <- c(levels(tree175$species), "UNK")
tree175$species[is.na(tree175$species)] <- "UNK"
tree175<-tree175[c('year', 'year1','doy', 'archive', 'contact', 'project','type', 'size', 'lat', 'long', 'obs.exp', 'treatment', 'treat.year', 'tract', 'site', 'plot', 'subplot', 'subsize', 'tree', 'species', 'dbh', 'method', 'min.dbh', 'interval', 'dbhprior', 'cond', 'demography')]



#HF069. EMS Biometry
#Note: read in cleaned-up input file by Evan Goldman, hf069-11-trees2.csv. Updated July 2016.

tree069a<-read.csv("hf069-11-trees2.csv" )
summary(tree069a)
tree069a<- rename(tree069a,c('jday'='doy','spp'='species','tag'='tree'))
tree069a<-subset(tree069a, !is.na(tree069a$dbh) & !is.na(tree069a$species)) #note ABP -- this removes 6 rows only
levels(as.factor(tree069a$species))


#tree conditon
tree069a$cond <- revalue(tree069a$tree.type, c("live" = "L", "dead" ="M","rcrt"="R","und"="U"))

#removed ac, ab, and eh from list (elg)
remove069 <- which(tree069a$species %in% c("fpc", "haw", "hbb", "spi" ,"ss", "nwr"))
tree069a <- tree069a[-remove069,] 

#removed spp names with white space added understory synonyms (ab = beech, ac = chestnut, eh= hem) (elg)
tree069a$species<-revalue(tree069a$species, c( "wb"="BEPA", "ash"="FRAM", "bb"="BELE", "beech"="FAGR", "bo"="QUVE", "cherry"="PRSE", "chestnut"="CADE", "gb"="BEPO", "hem"="TSCA", "rm"="ACRU", "ro"="QURU", "rp"="PIRE", "sm"="ACPE", "wb"=="BEPA", "wh"="HAVI", "wo"="QUAL", "wp"="PIST", "ws"="PIGL", "yb"="BEAL" ))
tree069a$species<-as.factor(tree069a$species)

#remove duplicated recruitment and mortality events
bad.ones<-rep(F,nrow(tree069a))


bad.ones[tree069a$plot=="C4"&tree069a$tree==475&!is.na(tree069a$tree)]<-T  #this tree never actually made it above 10cm DBH
bad.ones[tree069a$plot=="D1"&tree069a$tree==537&tree069a$year%in% 1998:2005&!is.na(tree069a$tree)]<-T
bad.ones[tree069a$plot=="E2"&tree069a$tree==735&tree069a$year%in% 1993:2002&!is.na(tree069a$tree)]<-T
bad.ones[tree069a$plot=="E4"&tree069a$tree==858&!is.na(tree069a$tree)]<-T
bad.ones[tree069a$plot=="F3"&tree069a$tree==535&tree069a$year==2002&!is.na(tree069a$tree)]<-T
bad.ones[tree069a$plot=="G5"&tree069a$tree==288&tree069a$year%in% 1998:2002&!is.na(tree069a$tree)]<-T

tree069a<-tree069a[!bad.ones,]

#sort the data
tree069a<-arrange(tree069a, year, plot, tree, -doy)



#keep only one dbh meas per year, max
#added cond (elg)
tree069<-ddply(tree069a,c("year","plot","site","tree","species","cond"),summarise,dbh=max(dbh))


tree069$project<-"ems"
tree069$archive<-"hf069"
tree069$contact<-"munger"
tree069$tract<-"PH"
tree069$type<-"hardwood"
tree069$size<-ifelse(tree069$plot %in% c("A4", "A5", "B5") & tree069$site=="ems" & tree069$year>2000,706.8583,ifelse(tree069$site=="harv" & tree069$year>2000,706.8583,314.1593))

tree069$lat<-42.54
tree069$long<--72.17
tree069$obs.exp<-ifelse(tree069$plot %in% c("A4", "A5", "B5") & tree069$year<1999,'obs', ifelse(tree069$site=="harv","exp","obs"))
tree069$treatment<-ifelse(tree069$plot %in% c("A4", "A5", "B5") & tree069$year<1999, NA, ifelse(tree069$site=="harv","harvest",NA))
tree069$treat.year<-ifelse(tree069$treatment=="harvest",2001,NA)
tree069$method<-"dendro"
tree069$method[tree069$year==1993]<-"dbh"
tree069$doy<-NA

#split understory from main tree data
understory069<-tree069[tree069$cond=="U",]
tree069<-tree069[tree069$cond!="U",]

understory069$project <- "ems-understory"
understory069$cond<-NA



#sampling interval

#calculate interval for recruits

#this script assumes that all plots are samples at every recruitment survey.
#if a plot stops being sampled that's fine, but if new plots are added this 
#script may need to be modified
#as long as new plots are added during a recruitment year
#(as is the case with plots X1-X6) the script will work fine

tree069$interval<- NA 
ind<-tree069$cond=="R" # index for recruitment data
rcrt.year<-tree069$year[ind] #year column from recruitment data
years<-sort(unique(tree069$year[ind])) #years when there was a recruitment survey
interval<-diff(c(1993,sort(unique(tree069$year[ind])))) #difference between years with recruitment surveys
tree069$interval[ind]<-mapvalues(rcrt.year,years,interval)

#calculate interval for live trees
plots<-unique(tree069$plot)
for(pl in plots){
  years<-unique(tree069$year[tree069$plot==pl])
  prev.yr<-NA
  for(yr in years){
    tree069$interval[tree069$plot==pl&tree069$year==yr&tree069$cond=="L"]<-yr-prev.yr
    prev.yr<-yr  
  }
}

understory069$interval<-NA

#prior DBH
understory069$dbhprior<-NA
out<-NULL
tree069$dbhprior <- NA
for(i in 1:nrow(tree069)){
  if(tree069$cond[i]=="L"){
    ind<-which(tree069$plot==tree069$plot[i]&tree069$tree==tree069$tree[i]&tree069$year==tree069$year[i]-tree069$interval[i])  
    if(length(ind)==1){
      tree069$dbhprior[i]<-tree069$dbh[ind]
    }else if(length(ind)>1){
      out<-rbind(out,c(tree069[i,c("plot","tree","year")],i))
    }
  }
}
#and, give 10cm to the recruits
tree069$dbhprior<-ifelse(tree069$cond=='R', 10, tree069$dbhprior)

# Demography
tree069$demography <- 'yes'
understory069$demography <- 'no'
tree069<-rbind(tree069,understory069)
tree069$subplot<-NA
tree069$subsize<-NA
tree069$year1<-tree069$year
tree069$min.dbh<-ifelse(tree069$project=='ems', 10, 1)
tree069<-tree069[c('year','year1', 'doy', 'archive', 'contact', 'project','type', 'size', 'lat', 'long', 'obs.exp', 'treatment', 'treat.year', 'tract', 'site', 'plot', 'subplot', 'subsize', 'tree', 'species', 'dbh', 'method', 'min.dbh', 'interval', 'dbhprior', 'cond', 'demography')]


ABP.8demography<-rbind(tree002, tree008, tree031, tree032, tree036, tree053,tree069, tree126 )
ABP.8demography$archive<-as.factor(ABP.8demography$archive)
ABP.8demography$contact<-as.factor(ABP.8demography$contact)
ABP.8demography$project<-as.factor(ABP.8demography$project)
ABP.8demography$type<-as.factor(ABP.8demography$type)
ABP.8demography$obs.exp<-as.factor(ABP.8demography$obs.exp)
ABP.8demography$treatment<-as.factor(ABP.8demography$treatment)
ABP.8demography$tract<-as.factor(ABP.8demography$tract)
ABP.8demography$site<-as.factor(ABP.8demography$site)
ABP.8demography$plot<-as.factor(ABP.8demography$plot)
ABP.8demography$method<-as.factor(ABP.8demography$method)
ABP.8demography$cond<-as.factor(ABP.8demography$cond)
ABP.8demography$demography<-as.factor(ABP.8demography$demography)
ABP.8demography<-ABP.8demography[c('year', 'doy', 'archive', 'contact', 'project','type', 'size', 'lat', 'long', 'obs.exp', 'treatment', 'treat.year', 'tract', 'site', 'plot', 'subplot', 'subsize', 'tree', 'species', 'dbh', 'method', 'interval', 'dbhprior', 'cond', 'demography')]

write.table(ABP.8demography, "demog8_nonotesMay11.csv", sep = ",", row.names = FALSE)

##### HF149 DATA INCORPORATED FALL 2018, THIS NOT USED ###############
#HF149. Dendro bands in plots around the hemlock tower
#Mortality can be found in the notes  ('dead'), although dead trees continue to be listed with NA for dbh
#recruitment possibly in notes as 'est 20XX' but not sure.

tree149<-read.csv("hf149-01-hem-dendro.csv")
head(tree149)
summary(tree149)
levels(as.factor(tree149$species))
#NYSY misspelled in this dataset; BENI is actually BELE (only BENI in entire compilation & ABP field checked the tree)
tree149$species<-revalue(tree149$species, c( "NYSA"="NYSY", "BENI"='BELE'))  
tree149$dbh<-ifelse(tree149$year==2012 & tree149$new.band==2012,(tree149$circ2012+tree149$caliper)/3.141593,(tree149$orig.circ+tree149$caliper)/3.141593)

tree149<- rename(tree149,c('id'='tree'))

tree149$doy<-NA
tree149$project<-"hk"
tree149$archive<-"hf149"
tree149$contact<-"nicoll"
tree149$tract<-"PH"
tree149$site<-"hemlock"
tree149$type<-"conifer"
tree149$size<-pi*6^2
tree149$lat<-42.54
tree149$long<--72.1825
tree149$obs.exp<-"obs"
tree149$treatment<-NA
tree149$treat.year<-NA
tree149$method<-"dendro"
tree149$notes<-NA
tree149$interval<-NA
tree149$dbhprior<-NA
tree149$cond<-'L'
tree149$demography<-'no'
tree149$subplot<-NA
tree149$subsize<-NA
tree149$year1<-tree149$year
tree149$min.dbh<-15
tree149<-tree149[c('year', 'year1','doy', 'archive', 'contact', 'project','type', 'size', 'lat', 'long', 'obs.exp', 'treatment', 'treat.year', 'tract', 'site', 'plot', 'subplot', 'subsize', 'tree', 'species', 'dbh', 'method', 'min.dbh','interval', 'dbhprior', 'cond', 'demography')]



#HF039 (PHVEG). Individual trees NOT tracked

tree039a<-read.csv("hf039-LiveTrees379213_169plots.csv")

#ADD NEW ROWS for multiple stems in 1937 only
tree039.37<-subset(tree039a, tree039a$year==1937)
tree039.92.14<-subset(tree039a, tree039a$year %in% c(1992,2013))

tree039.37all <- tree039.37[rep(seq_len(nrow(tree039.37)), tree039.37[,5]), ]

tree039<-rbind(tree039.37all,tree039.92.14)

tree039$size<-tree039$size_ha*10000
tree039$notes<-NA

tree039<-tree039[,c(1:4,14:15)]
tree039<- rename(tree039,c("dbh_cm"="dbh"))

tree039$tree<-NA
tree039$doy<-NA
tree039$project<-"ph-veg"
tree039$archive<-"hf039"
tree039$contact<-"barker-plotkin"
tree039$tract<-"PH"
tree039$site<-"PH"
tree039$lat<-42.5
tree039$long<--72.2
tree039$obs.exp<-"obs"
tree039$treatment<-NA
tree039$treat.year<-NA
tree039$method<-"dbh"


#tree039$type
phtree<-subset(tree039, tree039$year==1992)
phtree<-phtree[,c(2:4)]
sp<-ddply(phtree, c("plot","species"), summarise, count=length(dbh))
spmax<-ddply(sp,c('plot'),function(x) x[which(x$count==max(x$count)),])
spmax$type<-ifelse(spmax$species %in% c("PI","PIRE"  ,"PIRU"  ,"PIST" ,"TSCA"), "conifer","hardwood")
spmax<-spmax[,c(1,3:4)]
spmax<-unique(spmax)
tree039<-merge(tree039,spmax,by="plot",all.x=T)
tree039<-tree039[,-20]
tree039$interval<-NA
tree039$dbhprior<-NA
tree039$cond<-'L'
tree039$demography<-'no'
tree039$subplot<-NA
tree039$subsize<-NA
tree039$year1<-tree039$year
tree039$min.dbh<-NA #it is 2 inches in 1937, but 2.5 cm in 1992 & 2013
tree039<-tree039[c('year', 'year1','doy', 'archive', 'contact', 'project','type', 'size', 'lat', 'long', 'obs.exp', 'treatment', 'treat.year', 'tract', 'site', 'plot', 'subplot', 'subsize', 'tree', 'species', 'dbh', 'method', 'min.dbh', 'interval', 'dbhprior', 'cond', 'demography')]



#HF041. Pisgah. Individual trees NOT tracked systematically.
tree041<-read.csv("file:///C:/Users/aabarker/Dropbox/HF C Synthesis/Data/live trees/live tree data & code/hf041-01-tree-2014.csv")
summary(tree041)
tree041<-subset(tree041,tree041$cond=="L")
tree041<- rename(tree041,c('tag'='tree'))
tree041<-tree041[,-4]

tree041$doy<-NA
tree041$project<-"pisgah"
tree041$archive<-"hf041"
tree041$contact<-"foster"
tree041$tract<-"PISGAH"
tree041$site<-"pisgah"
tree041$type<-"conifer"
tree041$size<-20^2
tree041$lat<-42.83
tree041$long<--72.44
tree041$obs.exp<-"obs"
tree041$treatment<-NA
tree041$treat.year<-NA
tree041$method<-"dbh"
tree041$interval<-NA
tree041$dbhprior<-NA
tree041$cond<-'L'
tree041$demography<-'no'
tree041$subplot<-NA
tree041$subsize<-NA
tree041$year1<-tree041$year
tree041$min.dbh<-2
tree041<-tree041[c('year', 'year1','doy', 'archive', 'contact', 'project','type', 'size', 'lat', 'long', 'obs.exp', 'treatment', 'treat.year', 'tract', 'site', 'plot', 'subplot', 'subsize', 'tree', 'species', 'dbh', 'method', 'min.dbh', 'interval', 'dbhprior', 'cond', 'demography')]


#HF213
#Added 22 January 2015.
#Day measured is available for these, but all other datasets have 'NA' for doy so I'm not going to make the effort here.

tree213<-read.csv("hf213-01.csv")

tree213.2009<-tree213[,c(2,3,4,5, 6, 9, 10)]
tree213.2009<-subset(tree213.2009, !is.na(tree213.2009$DBH09))
tree213.2009$year<-2009
tree213.2009$tree<-(((tree213.2009$Tag)*10))
tree213.2009$tree<-tree213.2009$tree+tree213.2009$Num # Tag numbers are not unique; some tags are used for multiple-stem trees, identified by Num. So to make each unique but preserve order, multiply Tag by 10 then add Num
tree213.2009$plot<-tree213.2009$Plot
tree213.2009$subplot<-paste(tree213.2009$Plot,tree213.2009$Sub)
tree213.2009<- rename(tree213.2009,c('Spp'='species',"DBH09"="dbh","Field_Notes09"="notes"))

tree213.2011<-tree213[,c(2,3,4,5, 6, 12, 13)]
tree213.2011<-subset(tree213.2011, !is.na(tree213.2011$DBH11))
tree213.2011$year<-2011
tree213.2011$tree<-(((tree213.2011$Tag)*10))
tree213.2011$tree<-tree213.2011$tree+tree213.2011$Num # Tag numbers are not unique; some tags are used for multiple-stem trees, identified by Num. So to make each unique but preserve order, multiply Tag by 10 then add Num
tree213.2011$plot<-tree213.2011$Plot
tree213.2011$subplot<-paste(tree213.2011$Plot,tree213.2011$Sub)
tree213.2011<- rename(tree213.2011,c('Spp'='species',"DBH11"="dbh","Field_Notes11"="notes"))

tree213.2012<-tree213[,c(2,3,4,5, 6, 15, 16)]
tree213.2012<-subset(tree213.2012, !is.na(tree213.2012$DBH12)& tree213.2012$Field_Notes12 !='dead')
tree213.2012$year<-2012
tree213.2012$tree<-(((tree213.2012$Tag)*10))
tree213.2012$tree<-tree213.2012$tree+tree213.2012$Num # Tag numbers are not unique; some tags are used for multiple-stem trees, identified by Num. So to make each unique but preserve order, multiply Tag by 10 then add Num
tree213.2012$plot<-tree213.2012$Plot
tree213.2012$subplot<-paste(tree213.2012$Plot,tree213.2012$Sub)
tree213.2012<- rename(tree213.2012,c('Spp'='species',"DBH12"="dbh","Field_Notes12"="notes"))

tree213.2013<-tree213[,c(2,3,4,5, 6, 18, 19, 21)]
tree213.2013<-subset(tree213.2013, !is.na(tree213.2013$DBH13) & tree213.2013$Mortality13 !='D')
tree213.2013$year<-2013
tree213.2013$tree<-(((tree213.2013$Tag)*10))
tree213.2013$tree<-tree213.2013$tree+tree213.2013$Num # Tag numbers are not unique; some tags are used for multiple-stem trees, identified by Num. So to make each unique but preserve order, multiply Tag by 10 then add Num
tree213.2013$plot<-tree213.2013$Plot
tree213.2013$subplot<-paste(tree213.2013$Plot,tree213.2013$Sub)
tree213.2013<- rename(tree213.2013,c('Spp'='species',"DBH13"="dbh","Field_Notes13"="notes"))
names(tree213.2013)
tree213.2013<-tree213.2013[c(1:6, 8:12)]

tree213.2014<-tree213[,c(2,3,4,5, 6, 23, 24, 26)]
tree213.2014<-subset(tree213.2014, !is.na(tree213.2014$DBH14) & tree213.2014$Mortality14 !='D')
tree213.2014$year<-2014
tree213.2014$tree<-(((tree213.2014$Tag)*10))
tree213.2014$tree<-tree213.2014$tree+tree213.2014$Num # Tag numbers are not unique; some tags are used for multiple-stem trees, identified by Num. So to make each unique but preserve order, multiply Tag by 10 then add Num
tree213.2014$plot<-tree213.2014$Plot
tree213.2014$subplot<-paste(tree213.2014$Plot,tree213.2014$Sub)
tree213.2014<- rename(tree213.2014,c('Spp'='species',"DBH14"="dbh","Field_Notes14"="notes"))
tree213.2014<-tree213.2014[c(1:6, 8:12)]

names(tree213.2009)
names(tree213.2011)
names(tree213.2012)
names(tree213.2013)
names(tree213.2014)

tree213<-rbind(tree213.2009, tree213.2011, tree213.2012, tree213.2013, tree213.2014)
summary(tree213)
str(tree213)
tree213$species
tree213$species<-revalue(tree213$species, c('ACRU'='ACRU',"PRSE2"="PRSE","ACSA3"="ACSA", "BEAL2"="BEAL","BELE"="BELE" ,"FAGR"="FAGR","NYSY"="NYSY", "PIRE"="PIRE","PIST"="PIST","QUVE"="QUVE","TSCA"="TSCA", "BEPA"="BEPA", "CADE"="CADE", "CATO6"="CASP", "FRAM"="FRAM", "HAVI4"="HAVI" , "PIRU"= "PIRU","POGR4"="POGR", "QUAL"="QUAL", "QURU"="QURU"))
plot213<-read.csv("hf213plot.csv") #plot file has type, lat, long, tract
plot213$plot<-plot213$site
tree213<-merge(tree213,plot213,by="plot")

tree213$doy<-NA
tree213$project<-"demography-carb"
tree213$site<-NA
tree213$archive<-"hf213"
tree213$contact<-"dietze"
tree213$size<-225*4
tree213$subsize<-225
tree213$obs.exp<-"obs"
tree213$treatment<-NA
tree213$treat.year<-NA
tree213$method<-"dbh"
tree213$plot<-as.factor(tree213$plot)
tree213$interval<-NA
tree213$dbhprior<-NA
tree213$cond<-'L'
tree213$demography<-'no'
tree213$year1<-tree213$year
tree213$min.dbh<-5
tree213<-tree213[c('year', 'year1','doy', 'archive', 'contact', 'project','type', 'size', 'lat', 'long', 'obs.exp', 'treatment', 'treat.year', 'tract', 'site', 'plot', 'subplot', 'subsize', 'tree', 'species', 'dbh', 'method', 'min.dbh', 'interval', 'dbhprior', 'cond', 'demography')]


#HF002
library(dplyr)
# Trees in control plot
tree002c<-read.csv("file:///C:/Users/aabarker/Dropbox/HF C Synthesis/Data/live trees/live tree data & code/hf002-01-control15.csv") 
#Trees in manipulated plot
tree002e<-read.csv("file:///C:/Users/aabarker/Dropbox/HF C Synthesis/Data/live trees/live tree data & code/hf002-01-experiment15.csv") 

tree002c3<-subset(tree002c, tree002c$year %in%c(1990, 1996, 2000, 2005, 2010, 2015), select=c(year, tree, species, dbh, cond)) 
tree002c2<-subset(tree002c3, (tree002c3$year==1990 & tree002c3$cond=='D'))
tree002c1<-anti_join(tree002c3, tree002c2, by='tree')
tree002c1$plot<-'control plot'
tree002c1$dbh<-as.numeric(as.character(tree002c1$dbh))

# interval & dbhprior
myFun <- function(x){
  n <- nrow(x)
  x$interval <- c(NA,diff(x$year))
  x$dbhprior <- c(NA,head(x$dbh,n-1))
  x
}
#then
by(tree002c1,tree002c1$tree,FUN=myFun)
#then, If you want to put all the pieces back together again, we can use do.call and rbind:
tree002c2<- do.call(rbind,by(tree002c1,tree002c1$tree,FUN=myFun))

tree002e3<-subset(tree002e, tree002e$year %in%c(1990, 1996, 2000, 2005, 2010, 2015), select=c(year, tree, species, dbh, cond)) 
tree002e2<-subset(tree002e3, (tree002e3$year==1990 & tree002e3$cond=='D'))
tree002e1<-anti_join(tree002e3, tree002e2, by='tree')
tree002e1$plot<-"experimental plot"
str(tree002e1)
#then
by(tree002e1,tree002e1$tree,FUN=myFun)
#then, If you want to put all the pieces back together again, we can use do.call and rbind:
tree002e2<- do.call(rbind,by(tree002e1,tree002e1$tree,FUN=myFun))

# change l to L and moribund (M) to L
tree002a<-rbind(tree002e2,tree002c2)
tree002a$cond[tree002a$cond=='1']<-'L'
tree002a$cond[tree002a$cond=='M']<-'L'
summary(tree002a)

#subset the dead trees so that a tree is included only the first year it is dead (remove subsequent listings)
#Tree 1668 gets dropped (201 & 2015) at this point, which is good because it is actually the same as tree 703.
tree002D<-subset(tree002a, tree002a$cond=='D')
tree002L<-subset(tree002a, tree002a$cond!='D')
tree002D<-tree002D[!duplicated(tree002D[,c("plot", "tree", 'cond')]),]
tree002<-rbind(tree002L, tree002D)
tree002 <- tree002[order(tree002$plot, tree002$tree, tree002$year),] 
tree002$cond<-as.character(tree002$cond)
tree002$cond<-ifelse(tree002$tree>1000 & tree002$year==2010, 'R', tree002$cond)
tree002$cond<-ifelse(tree002$tree>2000 & tree002$year==2015, 'R', tree002$cond)
tree002$cond<-ifelse(tree002$cond=='D', 'M', tree002$cond)
tree002$cond<-ifelse(tree002$cond=='L' & is.na(tree002$dbh), 'miss', tree002$cond)
tree002$cond<-as.factor(tree002$cond)
# Are there any missed dbh's? That is, cond=L but dbh is.na?
tree002R<-subset(tree002, tree002$cond=='L' & is.na(tree002$dbh))

summary(tree002)


#Recruits - 2010 all recruits (1990-2010) added, which might be a weird pulse.
# hf002r_url<-getURL("http://harvardforest.fas.harvard.edu/sites/harvardforest.fas.harvard.edu/files/data/p00/hf002/hf002-12-recruitmap.csv")
# tree002recruits10<-read.csv(text=hf002r_url)

tree002$dbhprior<-ifelse(tree002$cond=='R', 5, tree002$dbhprior)
tree002$doy<-NA
tree002$project<-"sim-hurricane"
tree002$archive<-"hf002"
tree002$contact<-"barker-plotkin"
tree002$tract<-"TS"
tree002$site<-"TS"
tree002$type<-"hardwood"
tree002$size<-ifelse(tree002$plot == 'control plot', 6000, 8000)
tree002$lat<-42.49
tree002$long<--72.2
tree002$obs.exp<-ifelse(tree002$plot == 'control plot',"obs", "exp")
tree002$treatment<-ifelse(tree002$plot == 'control plot',NA, 'pulldown')
tree002$treat.year<-ifelse(tree002$plot == 'control plot',NA, 1990)
tree002$method<-"dbh"
tree002$demography<-'yes'
tree002$subplot<-NA
tree002$subsize<-NA
tree002$year1<-tree002$year
tree002$min.dbh<-5
tree002<-tree002[c('year', 'year1','doy', 'archive', 'contact', 'project','type', 'size', 'lat', 'long', 'obs.exp', 'treatment', 'treat.year', 'tract', 'site', 'plot', 'subplot', 'subsize', 'tree', 'species', 'dbh', 'method', 'min.dbh', 'interval', 'dbhprior', 'cond', 'demography')]

#RBIND ALL DATASETS

all_trees<-rbind(tree002,tree008,tree031,tree032,tree036,tree039,tree041,tree053,tree069,tree126,tree149,tree162,tree175, tree213)

summary(all_trees)

all_trees$archive<-as.factor(all_trees$archive)
all_trees$contact<-as.factor(all_trees$contact)
all_trees$project<-as.factor(all_trees$project)
all_trees$type<-as.factor(all_trees$type)
all_trees$obs.exp<-as.factor(all_trees$obs.exp)
all_trees$treatment<-as.factor(all_trees$treatment)
all_trees$tract<-as.factor(all_trees$tract)
all_trees$site<-as.factor(all_trees$site)
all_trees$plot<-as.factor(all_trees$plot)
all_trees$method<-as.factor(all_trees$method)
all_trees$cond<-as.factor(all_trees$cond)
all_trees$demography<-as.factor(all_trees$demography)

all_trees$species<-droplevels(all_trees$species)
all_trees$cond<-droplevels(all_trees$cond)

names(all_trees)

all_trees$year<-as.numeric(all_trees$year)
all_trees$year1<-as.numeric(all_trees$year1)

write.table(all_trees, "C:/Users/aabarker/Dropbox/HF C Synthesis/Data/live trees/hf-c-trees-gmr-2oct17.csv", sep = ",", row.names = FALSE)

