#HF-C-TREES-GMR (Growth, Mortality & Recruitment)
# script to read, format, and combine tree data. For individually tagged tree datasets, includes mortality & recruitment also.
#addition of Hemlock Tower Dendrometer Plots
#Data set cleaned and annualized by Loic D'Orangeville, 2017-2018
#format to match hf c live tree file, but keep separate, as a last-minute addition.
#modified from a script written by L. Nicoll, Sept 2014 & revised Jan 2015, April 2016 & Nov 2016 by A. Barker Plotkin
#September 2017 revisions ABP. Goals: add dbhprior for recruits based on minimum dbh per study.

setwd('C:/Users/aabarker/Dropbox/HF C Synthesis/Data/live trees/live tree data & code/')
library(reshape2)
library(plyr) 

#HF069. EMS Biometry
#Note: read in cleaned-up input file by Evan Goldman, hf069-11-trees2.csv. Updated July 2016.

tree069a<-read.csv("hf069-11-trees2.csv" )
summary(tree069a)
tree069a<- rename(tree069a,c('jday'='doy','spp'='species','tag'='tree'))
tree069a<-subset(tree069a, !is.na(tree069a$dbh) & !is.na(tree069a$species)) #note ABP -- this removes 6 rows only
levels(as.factor(tree069a$species))


#tree conditon
tree069a$cond <- revalue(tree069a$tree.type, c("live" = "L", "dead" ="M","rcrt"="R","und"="U"))

#removed ac, ab, and eh from list (elg)
remove069 <- which(tree069a$species %in% c("fpc", "haw", "hbb", "spi" ,"ss", "nwr"))
tree069a <- tree069a[-remove069,] 

#removed spp names with white space added understory synonyms (ab = beech, ac = chestnut, eh= hem) (elg)
tree069a$species<-revalue(tree069a$species, c( "wb"="BEPA", "ash"="FRAM", "bb"="BELE", "beech"="FAGR", "bo"="QUVE", "cherry"="PRSE", "chestnut"="CADE", "gb"="BEPO", "hem"="TSCA", "rm"="ACRU", "ro"="QURU", "rp"="PIRE", "sm"="ACPE", "wb"=="BEPA", "wh"="HAVI", "wo"="QUAL", "wp"="PIST", "ws"="PIGL", "yb"="BEAL" ))
tree069a$species<-as.factor(tree069a$species)

#remove duplicated recruitment and mortality events
bad.ones<-rep(F,nrow(tree069a))


bad.ones[tree069a$plot=="C4"&tree069a$tree==475&!is.na(tree069a$tree)]<-T  #this tree never actually made it above 10cm DBH
bad.ones[tree069a$plot=="D1"&tree069a$tree==537&tree069a$year%in% 1998:2005&!is.na(tree069a$tree)]<-T
bad.ones[tree069a$plot=="E2"&tree069a$tree==735&tree069a$year%in% 1993:2002&!is.na(tree069a$tree)]<-T
bad.ones[tree069a$plot=="E4"&tree069a$tree==858&!is.na(tree069a$tree)]<-T
bad.ones[tree069a$plot=="F3"&tree069a$tree==535&tree069a$year==2002&!is.na(tree069a$tree)]<-T
bad.ones[tree069a$plot=="G5"&tree069a$tree==288&tree069a$year%in% 1998:2002&!is.na(tree069a$tree)]<-T

tree069a<-tree069a[!bad.ones,]

#sort the data
tree069a<-arrange(tree069a, year, plot, tree, -doy)



#keep only one dbh meas per year, max
#added cond (elg)
tree069<-ddply(tree069a,c("year","plot","site","tree","species","cond"),summarise,dbh=max(dbh))


tree069$project<-"ems"
tree069$archive<-"hf069"
tree069$contact<-"munger"
tree069$tract<-"PH"
tree069$type<-"hardwood"
tree069$size<-ifelse(tree069$plot %in% c("A4", "A5", "B5") & tree069$site=="ems" & tree069$year>2000,706.8583,ifelse(tree069$site=="harv" & tree069$year>2000,706.8583,314.1593))

tree069$lat<-42.54
tree069$long<--72.17
tree069$obs.exp<-ifelse(tree069$plot %in% c("A4", "A5", "B5") & tree069$year<1999,'obs', ifelse(tree069$site=="harv","exp","obs"))
tree069$treatment<-ifelse(tree069$plot %in% c("A4", "A5", "B5") & tree069$year<1999, NA, ifelse(tree069$site=="harv","harvest",NA))
tree069$treat.year<-ifelse(tree069$treatment=="harvest",2001,NA)
tree069$method<-"dendro"
tree069$method[tree069$year==1993]<-"dbh"
tree069$doy<-NA

#split understory from main tree data
understory069<-tree069[tree069$cond=="U",]
tree069<-tree069[tree069$cond!="U",]

understory069$project <- "ems-understory"
understory069$cond<-NA



#sampling interval

#calculate interval for recruits

#this script assumes that all plots are samples at every recruitment survey.
#if a plot stops being sampled that's fine, but if new plots are added this 
#script may need to be modified
#as long as new plots are added during a recruitment year
#(as is the case with plots X1-X6) the script will work fine

tree069$interval<- NA 
ind<-tree069$cond=="R" # index for recruitment data
rcrt.year<-tree069$year[ind] #year column from recruitment data
years<-sort(unique(tree069$year[ind])) #years when there was a recruitment survey
interval<-diff(c(1993,sort(unique(tree069$year[ind])))) #difference between years with recruitment surveys
tree069$interval[ind]<-mapvalues(rcrt.year,years,interval)

#calculate interval for live trees
plots<-unique(tree069$plot)
for(pl in plots){
  years<-unique(tree069$year[tree069$plot==pl])
  prev.yr<-NA
  for(yr in years){
    tree069$interval[tree069$plot==pl&tree069$year==yr&tree069$cond=="L"]<-yr-prev.yr
    prev.yr<-yr  
  }
}

understory069$interval<-NA

#prior DBH
understory069$dbhprior<-NA
out<-NULL
tree069$dbhprior <- NA
for(i in 1:nrow(tree069)){
  if(tree069$cond[i]=="L"){
    ind<-which(tree069$plot==tree069$plot[i]&tree069$tree==tree069$tree[i]&tree069$year==tree069$year[i]-tree069$interval[i])  
    if(length(ind)==1){
      tree069$dbhprior[i]<-tree069$dbh[ind]
    }else if(length(ind)>1){
      out<-rbind(out,c(tree069[i,c("plot","tree","year")],i))
    }
  }
}
#and, give 10cm to the recruits
tree069$dbhprior<-ifelse(tree069$cond=='R', 10, tree069$dbhprior)

#same thing using sapply
#ind<-sapply(1:nrow(tree069),function(i){which(tree069$plot==tree069$plot[i]&tree069$tree==tree069$tree[i]&tree069$year==tree069$year[i]-tree069$interval[i])[1]})
#ind[sapply(ind,length)==0]<-NA
#ind<-unlist(ind)
#tree069$dbhprior <- tree069$dbh[ind]


# Demography
tree069$demography <- 'yes'
understory069$demography <- 'no'
tree069<-rbind(tree069,understory069)
tree069$subplot<-NA
tree069$subsize<-NA
tree069$year1<-tree069$year
tree069$min.dbh<-ifelse(tree069$project=='ems', 10, 1)
tree069<-tree069[c('year','year1', 'doy', 'archive', 'contact', 'project','type', 'size', 'lat', 'long', 'obs.exp', 'treatment', 'treat.year', 'tract', 'site', 'plot', 'subplot', 'subsize', 'tree', 'species', 'dbh', 'method', 'min.dbh', 'interval', 'dbhprior', 'cond', 'demography')]


ABP.8demography<-rbind(tree002, tree008, tree031, tree032, tree036, tree053,tree069, tree126 )
ABP.8demography$archive<-as.factor(ABP.8demography$archive)
ABP.8demography$contact<-as.factor(ABP.8demography$contact)
ABP.8demography$project<-as.factor(ABP.8demography$project)
ABP.8demography$type<-as.factor(ABP.8demography$type)
ABP.8demography$obs.exp<-as.factor(ABP.8demography$obs.exp)
ABP.8demography$treatment<-as.factor(ABP.8demography$treatment)
ABP.8demography$tract<-as.factor(ABP.8demography$tract)
ABP.8demography$site<-as.factor(ABP.8demography$site)
ABP.8demography$plot<-as.factor(ABP.8demography$plot)
ABP.8demography$method<-as.factor(ABP.8demography$method)
ABP.8demography$cond<-as.factor(ABP.8demography$cond)
ABP.8demography$demography<-as.factor(ABP.8demography$demography)
ABP.8demography<-ABP.8demography[c('year', 'doy', 'archive', 'contact', 'project','type', 'size', 'lat', 'long', 'obs.exp', 'treatment', 'treat.year', 'tract', 'site', 'plot', 'subplot', 'subsize', 'tree', 'species', 'dbh', 'method', 'interval', 'dbhprior', 'cond', 'demography')]

write.table(ABP.8demography, "demog8_nonotesMay11.csv", sep = ",", row.names = FALSE)


#HF149. Dendro bands in plots around the hemlock tower
#Live Trees Only in this Dataset
#so - NO MORTALITY also NO RECRUITMENT (not measured)

tree149<-read.csv("HF149-loic2018.csv")
summary(tree149)
levels(as.factor(tree149$species))

tree149$doy<-NA
tree149$project<-"hk"
tree149$archive<-"hf149"
tree149$contact<-"vanscoy"
tree149$tract<-"PH"
tree149$site<-"hemlock"
tree149$type<-"conifer"
tree149$size<-pi*6^2
tree149$lat<-42.54
tree149$long<--72.1825
tree149$obs.exp<-"obs"
tree149$treatment<-NA
tree149$treat.year<-NA
tree149$method<-"dendro"
tree149$notes<-NA
tree149$interval<-1
tree149$cond<-'L'
tree149$demography<-'yes'
tree149$subplot<-NA
tree149$subsize<-NA
tree149$year1<-tree149$year
tree149$min.dbh<-15
tree149<-tree149[c('year', 'year1','doy', 'archive', 'contact', 'project','type', 'size', 'lat', 'long', 'obs.exp', 'treatment', 'treat.year', 'tract', 'site', 'plot', 'subplot', 'subsize', 'tree', 'species', 'dbh', 'method', 'min.dbh','interval', 'dbhprior', 'cond', 'demography')]
# subset of the 11 plots with no missing measurements
tree149.11<-subset(tree149, tree149$plot %in% c("195_147", "195_53", "210_149", "210_198", "225_49", "225_98",
                                                "240_50", "255_150", "255_47", "270_49", "270_96"))

summary(tree149.11)
tree149.11$species<-droplevels(tree149.11$species) #only TSCA, ACRU, PIST, QURU

write.table(tree149.11, "hk-149-11plots-nov2018.csv", sep = ",", row.names = FALSE)

#Now get biomass (current/prior aboveground; current/prior coarse roots)

# current biomass
tree149.11["biomassAF20"] <- NA
source('C:/Users/aabarker/Dropbox/HF C Synthesis/Data/live trees/live tree data & code/biomassAF20-nov2016.R')
#From rows 1 to the total number of rows, calculate the biomass of each tree and add it to the row of that tree and put it in the column biomass
for(i in 1:nrow(tree149.11)) {
  tree149.11$biomassAF20[i] <- biomassAF20(tree149.11$species[i], tree149.11$dbh[i])
}

# prior biomass
tree149.11["biomasspriorAF20"] <- NA
source('C:/Users/aabarker/Dropbox/HF C Synthesis/Data/live trees/live tree data & code/biomassAF20-nov2016.R')
#From rows 1 to the total number of rows, calculate the biomass of each tree and add it to the row of that tree and put it in the column biomass
for(i in 1:nrow(tree149.11)) {
  tree149.11$biomasspriorAF20[i] <- biomassAF20(tree149.11$species[i], tree149.11$dbhprior[i])
}


#CALCULATE COARSE ROOT BIOMASS BASED ON JENKINS et al. 2003 HW/SW RATIO
# coarse root (current) biomass ratio of total aboveground
tree149.11["rootratio"] <- NA
source('C:/Users/aabarker/Dropbox/HF C Synthesis/Data/live trees/live tree data & code/biomasscoarserootshwsw.R')
#From rows 1 to the total number of rows, calculate the biomass of each tree and add it to the row of that tree and put it in the column biomass
for(i in 1:nrow(tree149.11)) {
  tree149.11$rootratio[i] <- rootratio(tree149.11$species[i], tree149.11$dbh[i])
}

tree149.11["rootratioprior"] <- NA
source('C:/Users/aabarker/Dropbox/HF C Synthesis/Data/live trees/live tree data & code/biomasscoarserootshwsw.R')
#From rows 1 to the total number of rows, calculate the biomass of each tree and add it to the row of that tree and put it in the column biomass
for(i in 1:nrow(tree149.11)) {
  tree149.11$rootratioprior[i] <- rootratio(tree149.11$species[i], tree149.11$dbhprior[i])
}


### FOR THE ROOT BIOMASS QUESTION ONLY ###
tiny<-subset(tree149.11, tree149.11$dbh<2.5)
# because the ratios are meant for trees >2.5cm dbh, replace those rootratios with NA
tree149.11$rootratio<-ifelse(tree149.11$dbh<2.5, NA, tree149.11$rootratio)
tree149.11$rootratioprior<-ifelse(tree149.11$dbhprior<2.5, NA, tree149.11$rootratioprior)

#Make columns for current and prior coarse root biomass (kg)
tree149.11$coarserootKg<- tree149.11$biomassAF20*tree149.11$rootratio
tree149.11$coarserootKgprior<- tree149.11$biomasspriorAF20*tree149.11$rootratioprior


write.table(tree149.11, "hf149-11-biomass-by-tree-gmr-18nov18.csv", sep = ",", row.names = FALSE)

