# HF C synthesis - summarizing live tree biomass by plot.
# * is a data set that we didn't/can't track individual trees.
#hf002  sim-hurricane (1990-2015)
#hf008	chronicN (1989-2008)
#hf031  hemlock woodlot (1990-2014)
#hf032	lyford-grid (1969-2011)
#hf036  mapped-tree-plot (1990-2013)
#hf039*	ph-veg (1937, 1992, 2013)
#hf041*	pisgah (1990-2014)
#hf053	hemlock history (1995-2012)
#hf069	ems (1993-2014)
#hf126	hf-here (2004-2014)
#hf149*	hk 
#hf162*	p.biodiv (2007-2012)
#hf175*	hf.regen
#hf213*	demography-carb

library(plyr)
library(ggplot2)
library(reshape2)

alltree<-read.csv("c:/data/biomass-by-tree-gmr-2oct17.csv") 

# need to take out mortality to do this one.
alltreenoM<-subset(alltree, alltree$cond != 'M')
# and for cond=='miss' put in biomassprior & coarseroot prior
alltreenoM$biomassAF20<-ifelse(alltreenoM$cond=='miss', alltreenoM$biomasspriorAF20, alltreenoM$biomassAF20)
alltreenoM$coarserootKg<-ifelse(alltreenoM$cond=='miss', alltreenoM$coarserootKgprior, alltreenoM$coarserootKg)
 
# VARIOUS PROJECTS & PLOTS TO REMOVE FROM THE ANALYSIS. PICK & CHOOSE WHICH ARE APPROPRIATE.
# take out hk - I am very leery of the data quality. e.g., Some plot/year combinations have 0 biomass.
# take out pisgah - because not in same region (in New Hampshire)
atp<-subset(alltreenoM, !alltreenoM$project %in% c('hk', 'pisgah'))
# take out the 3 flooded EMS plots (observational; leaves in the harvested plots). Remove X4, not affected by harvest & meas only 2001.
atp<-subset(atp, !atp$plot %in% c("G3", "H3",'H4', 'X4'))
# designate harvested EMS plots  as 'exp' throughout their histories, so that we're comparing the same 34 plots over time in the observational summary.
atp$obs.exp<-ifelse(atp$plot %in% c('A4','A5','B5'), 'exp', as.character(atp$obs.exp))
#include only the 60 PHOREST plots measured in all 3 censuses
atp<-droplevels(atp)
levels (atp$project)
ph60<-subset(atp, atp$project == 'ph-veg' & atp$plot %in% c(1, 6, 8, 9, 13, 14, 15, 16, 18, 19, 24, 26, 27, 28, 30, 32, 40, 42, 47, 51, 56, 57, 58, 66, 68, 73, 76, 81, 82, 84, 86, 90, 93, 97, 99, 101, 106, 111, 112, 118, 125, 126, 127, 128, 130, 131, 132, 134, 141, 142, 143, 152, 154, 155, 161, 165, 166, 168, 180, 181))
atp<-subset(atp, atp$project != 'ph-veg')
atp<-rbind(atp, ph60)
#demography-carb. what is happening at the plot level?
#most of the trees in plot 6 were not measured in 2013. So - take out 2013, plot 6.
# So, here's the subset without plot 6 in 2013, and taking out 2009 since only 2 of the 8 plots were measured that year.
atp<-subset(atp, !(atp$project=='demography-carb' & atp$plot=='6' & atp$year1==2013))
atp<-subset(atp,!(atp$project=='demography-carb' & atp$year1==2009))
# Chronic N 2013 measurements seems like the diameters are way too high.
levels(atp$project)
atp<-subset(atp, !(atp$project =='chronicN'& atp$year1==2013))
summary(atp)

# Investigate what are remaining NAs for aboveground biomass & coarse root biomass
nobiomass<-subset(atp, is.na(atp$biomassAF20)) #some missed trees in the hurricane experiment
noroot<-subset(atp, is.na(atp$coarserootKg)) #mostly <2.5cm diameters, excluded.

# summarize by plot, year, and species (live biomass)
atp2<-ddply(atp, 
            c("project","year1","plot",'type',"size", 'obs.exp', 'species'), 
            summarise,
            plot.biom.kg=sum(biomassAF20, na.rm=T),
            root.biom.kg=sum(coarserootKg, na.rm=T))
atp2$plot.biom.gm2<-(atp2$plot.biom.kg/atp2$size)*1000
atp2$plot.C.gm2<-atp2$plot.biom.gm2/2
atp2$plot.rootbiomass.gm2<-(atp2$root.biom.kg/atp2$size)*1000
atp2$plot.rootC.gm2<-atp2$plot.rootbiomass.gm2/2

## using this output, assign each plot to a species group.
## K-means cluster analysis of species composition in most recent measurement of each tree plot
## biostats.R is a helper file from Kevin McGarrigal's Multivariate Statistics course at UMass Amherst

library(vegan)
library(cluster)
library(fpc)
library(mclust)
source('C:/Users/aabarker/Dropbox/HF C Synthesis/Data/Data&ScriptsToArchive/Trees/biostats.R')

summary(atp2)
levels(atp2$project)
atp3 <- atp2[order(atp2$species),] 
#flip the data to wide format so that each tree species is a column
wide <- reshape(atp3, v.names = "plot.biom.gm2", idvar = c('project', 'plot', 'year1'), timevar = "species", drop = c('size', 'type','plot.biom.kg' , 'root.biom.kg', 'plot.C.gm2','plot.rootbiomass.gm2', 'plot.rootC.gm2'),direction = "wide")
summary(wide)
# get only the most recent measurement of each plot
wide$projpl<-paste(wide$project, wide$plot)
wide<-wide[order(wide$projpl, -wide$year1),]
wide1<-subset(wide, !duplicated(projpl))
#take out phorest measured last in 1992, and discontinued ems plots
wide1<-subset(wide1, !wide1$year1 %in% c(1992,1998, 2000, 2001, 2007))
#take out experimental plots
wide1<-subset(wide1, wide1$obs.exp=='obs')
rownames(wide1) <- wide1[,54]
proj.plot<-subset(wide1, select=c(project, plot, year1))
summary(wide1)

##Examine data set and modify
str(wide1)
wide1[is.na(wide1)]<-0 #make the NAs zeroes
yall<-wide1[,-c(1:4,54)] #get the species alone


# remove species in none of the plots (species that existed in prior measurements of plots, especially 1937): QUBI,SOAM,ABBA, ULAM, ALIN, ULSP, LASP, POSP, PIRI, ROPS, PISY, QUCO, PRVI, ACSP, JUVI
# none (species that existed in prior measurements of plots, especially 1937): QUBI,SOAM,ABBA, ULAM, ALIN, ULSP, LASP, POSP, PIRI, ROPS, PISY, QUCO, PRVI, ACSP, JUVI
yall<-yall[, -which(numcolwise(sum)(yall)==0)] 

# In these 134 plots, there are 35 species that are non-zero
# narrow down to more important species. In this case, base on frequency & minimum total biomass
# which species are present in fewer than 5% of the plots? (5% of 134 is 6.7, so let's say >127 NAs)
# <200Mg & <5%: UNK, POGR, BEPO, PIRU, CASP, HAVI, PIGL, FRNI, CACA, PRPE, TIAM, PIAB, PISP, ACSC
# species with <200Mg total but in more than 5% of the plots: ACPE, NYSY, ACSA, CADE, OSVI, CAGL, CAOV, PRPE, BESP (keep these)
y.sub<-subset(yall, select = c(-plot.biom.gm2.UNK, -plot.biom.gm2.POGR, -plot.biom.gm2.BEPO, -plot.biom.gm2.PIRU, -plot.biom.gm2.CASP, -plot.biom.gm2.HAVI, -plot.biom.gm2.PIGL, -plot.biom.gm2.FRNI, -plot.biom.gm2.CACA, -plot.biom.gm2.PRPE, -plot.biom.gm2.TIAM, -plot.biom.gm2.PIAB, -plot.biom.gm2.PISP, -plot.biom.gm2.ACSC))
summary(y.sub)
#that leaves 21 species

#########################################################
#Standarize data by plot, to even out large differences in total biomass among plots.
#It doesn't make sense to me to standardize by species since they're all in the same units.
y.std<-data.stand(y.sub,method='standardize',margin='row',plot=FALSE) 

#scree plot to determine number of clusters
nhclus.scree(y.std,max.k=20)
#silhouette width close to 1 is good (5)
#within-cluster dissimilarity - choose 'elbow' (5 also good)

#kmeans
y.kmeans<-kmeans(y.std,5, nstart=20)
y.kmeans
y.kmeans$size
grp<-y.kmeans$cluster
kmean.grp<-cbind(proj.plot, grp, yall)

write.csv(kmean.grp, 'c:/data/work/kmean5-134plot.csv')
# this file is modified in excel to match with cluster names

## back to the summary by plot, and adding in each plots' cluster identity
# summarize live biomass
atp1<-ddply(atp, 
           c("project","year1","plot",'type',"size", 'obs.exp'),
           summarise,
           plot.biom.kg=sum(biomassAF20, na.rm=T),
           root.biom.kg=sum(coarserootKg, na.rm=T))


#calc biomass g/m2. plot.biomass is kg (to g is *1000) and size is m2 so net *1000.
atp1$plot.biom.gm2<-(atp1$plot.biom.kg/atp1$size)*1000
atp1$plot.C.gm2<-atp1$plot.biom.gm2/2
atp1$plot.rootbiomass.gm2<-(atp1$root.biom.kg/atp1$size)*1000
atp1$plot.rootC.gm2<-atp1$plot.rootbiomass.gm2/2


# Add cluster identity to each plot (the experimental plots don't have a group, and the ph-veg plots keep whatever group they are in 2013 back to 1992 & 1937)
cluster<-read.csv('C:/Users/aabarker/Dropbox/HF C Synthesis/Data/live trees/kmean5-134plot.csv')
str(cluster)
cluster<-subset(cluster, select=c('project', 'plot', 'NEWname'))
atp2 <- merge(atp1, cluster, by=c("project",'plot'), all=TRUE)
# simplify by type
atp2$type2<-ifelse(atp2$NEWname %in% c('maple-birch-ash', 'oak-maple'), 'hardwood', ifelse(atp2$NEWname=='pine-oak', 'pine', ifelse(atp2$NEWname=='red pine', 'RP', 'hemlock')))
#but hemlock removal plot 7 is hardwood, rather than pine-oak. This is based on the judgement of the study coI (A. Barker Plotkin)
atp2$type2<-ifelse(atp2$project=='hf-here'& atp2$plot==7, 'hardwood', atp2$type2)

## from here, one can summarize by study, by plot, by type. . . 

# observational plots only
atpobs<-subset(atp2, atp2$obs.exp=='obs')
atpobs<-droplevels(atpobs)
levels (atpobs$type2)

# current C stocks - subset most recent year by plot
atpobs$projplot<-paste(atpobs$project, atpobs$plot, sep='')
atpnow<-   ddply(atpobs, .(projplot), function(x) {
    transform(x[which.max(x$year1),], mval=year1)
  }, .drop=F)
atpnow<-droplevels(atpnow)

#Use this for numbers in Table 2 (group using the column 'type2' and compare hardwood vs. hemlock. Exclude RP (not in scope of analysis), and pine (too few plots of this type).
write.table(atpnow, 'c:/data/CurrentTreeCplotType.csv', sep = ",", row.names = FALSE)

# mean and sd C stocks using most recent measurement, by cluster, or type, or study
currentCcluster<-ddply(atpnow,c('type2'),
                       summarise,
                       n=length(plot),
                       meanC = mean(plot.C.gm2),
                       sdC=sd(plot.C.gm2),
                       meanRootC=mean(plot.rootC.gm2),
                       sdRootC=sd(plot.rootC.gm2))

## END OF THIS PART. To get at NPP, see 'trees-GMR-stocks-rates.R' & 'trees-GMR-stocks-rates-partII.R' ##