### 7 projects (exclude ChronicN) with individually tagged trees for growth, recruitment & mortality ###
library(ggplot2)
library(plyr)
library(reshape2)

##20NOV DO ALL THIS WITH MORT NOT MORT10##
### 18 November 2018 added 11 hk dendro plots with no missing measurements ###

# take biomass by tree and assign forest type
alltrees<-read.csv("C:/Users/aabarker/Dropbox/HF C Synthesis/Data/live trees/biomass-by-tree-gmr-2oct17.csv") 
hk<-read.csv("file:///C:/Users/aabarker/Dropbox/HF C Synthesis/Data/live trees/live tree data & code/hf149-11-biomass-by-tree-gmr-18nov18.csv")
alltreeshk<-rbind(alltrees,hk)
cluster<-read.csv('C:/Users/aabarker/Dropbox/HF C Synthesis/Data/live trees/kmean5-134plot.csv')
str(cluster)
cluster<-subset(cluster, select=c('project', 'plot', 'NEWname'))

alltreescl <- merge(alltreeshk, cluster, by=c("project","plot"),all.x=TRUE)#, all=TRUE
str(alltreescl)
#re-do conifer & hardwood
alltreescl$type2<-ifelse(alltreescl$NEWname %in% c('maple-birch-ash', 'oak-maple'), 'hardwood', ifelse(alltreescl$NEWname=='pine-oak', 'pine', ifelse(alltreescl$NEWname=='red pine', 'RP', 'hemlock')))
#but hemlock removal plot 7 is hardwood, rather than pine-oak, based on study investigator judgement.
alltreescl$type2<-ifelse(alltreescl$project=='hf-here'& alltreescl$plot==7, 'hardwood', alltreescl$type2)
#and all the hk plots are 'hemlock'
alltreescl$type2<-ifelse(alltreescl$project=='hk', 'hemlock', alltreescl$type2)

#Nov 2018 re-do summary of aboveground C by plot & year
live.biomass<-ddply(subset (alltreescl,alltreescl$cond %in% c('L','R')), 
                 c("project", "plot", "year1", "type2"), #type
                 summarise,
                 dens=length(plot),
                 size=sum(size)/length(size),
                 biomass.kg.plot=sum(biomassAF20, na.rm=TRUE),
                 Rootbiomass.kg.plot=sum(coarserootKg, na.rm=TRUE))
live.biomass$plot.biom.gm2<-(live.biomass$biomass.kg.plot/live.biomass$size)*1000
live.biomass$plot.root.gm2<-(live.biomass$Rootbiomass.kg.plot/live.biomass$size)*1000
live.biomass$TreeC.gm2<-live.biomass$plot.biom.gm2/2
live.biomass$RootC.gm2<-live.biomass$plot.root.gm2/2
write.table(live.biomass, 'C:/Users/aabarker/Dropbox/HF C Synthesis/Data/live trees/Cstocks-plotyearNov2018.csv', sep = ",", row.names = FALSE)
# get most recent year only in excel because I'm lazy and morally corrupt.
Cstock.now<-read.csv('file:///C:/Users/aabarker/Dropbox/HF C Synthesis/Data/live trees/Cstocks-mostrecent-obs-Nov2018.csv')

Cstocksprojyear<-ddply(Cstock.now, 
                       c("project", "year1"),
                       summarise,
                       n.plots=length(plot),
                       area.m2=sum(size),
                       LiveCA.gm2=mean(TreeC.gm2),
                       LiveCA.sd=sd(TreeC.gm2),
                       LiveCR.gm2=mean(RootC.gm2),
                       LiveCR.sd=sd(RootC.gm2))

Cstockstypenow<-ddply(Cstock.now, 
                       c("type2"),
                       summarise,
                       n.plots=length(plot),
                       area.m2=sum(size),
                       LiveCA.gm2=mean(TreeC.gm2),
                       LiveCA.sd=sd(TreeC.gm2),
                       LiveCR.gm2=mean(RootC.gm2),
                       LiveCR.sd=sd(RootC.gm2))

# subset only the studies that have individual tree re-measurements (ie demography)
demtrees<-subset(alltreescl, alltreescl$demography=='yes')
demtrees$project<-droplevels(demtrees$project)
str(demtrees)
levels(demtrees$project) #9 projects. 

#calculate aboveground & root increment
demtrees$ainc<-demtrees$biomassAF20-demtrees$biomasspriorAF20
demtrees$rinc<-demtrees$coarserootKg-demtrees$coarserootKgprior

neg<-subset(demtrees, demtrees$ainc<0)

#Background mortality rates
#subset of plots/treatments to include for background mortality calculations 
  # no chronicN, 
  # observational plots only
  # 34 consistently measured observational plots in ems (subset of 42 total; 3 removed 2001 after flooding & 3 other harvested 2001
  # subset of hf-here plot 7 that is in all 3 censuses (-158 tree; plot size = 6000m2)

mort.s<-subset(demtrees, demtrees$project !='chronicN' & demtrees$obs.exp=='obs' & !demtrees$plot %in% c('A4', 'A5', 'B5', "G3", "H3",'H4'))
mort.s$treatment<-droplevels(mort.s$treatment)
mort.s<-droplevels(mort.s)
summary(mort.s)

#now take out the trees in hf-here plot 7 that aren't in all 3 censuses, and change plot size to 6000m2
mort2<-subset(mort.s, mort.s$project !='hf-here')
simes<-subset(mort.s, mort.s$project=='hf-here')
simes7miss<-subset(simes, simes$cond=='miss')
library(dplyr)
simes.7.6000<-anti_join(simes, simes7miss, by='tree')
simes.7.6000$size<-ifelse(simes.7.6000$plot =='7', 6000, simes.7.6000$size)
#put it all back together
mort<-rbind(mort2,simes.7.6000)


## 25 March 2018. Show size distribution of trees that died versus trees that lived
## lumping all years (so individual trees show up each time they are measured. . .)
## panel by type2
mortLM<-subset (mort, mort$cond %in% c('L','M') & mort$type2!='RP')
hist<-ggplot(mortLM, aes(x=dbh, fill=cond)) + geom_density(alpha=.3)+
  facet_grid(.~type2)+
  scale_fill_discrete(name="",
                    breaks=c("L", "M"),
                    labels=c("Survived", "Died"))+
  labs(x="diameter (cm)")+
  theme_bw()+
  theme(panel.grid.major=element_blank(),
          legend.position=c(0.87, 0.8))
ggsave("c:/data/FigS3.tiff", hist, width=5, height=3, units = "in", dpi=600, compression = "lzw")

##############################################
#option to run this all with only trees >10cm
#will there be unintended consequences (eg. more NAs?)
 mort10<-subset(mort, mort$dbh>=10)
# total trees reduced from 47,953 to 33,684
##############################################

summary(mort)
summary(alltrees)
#by plot
miss<-subset(mort, mort$cond=='miss') #missed 155 trees
n.proj<-ddply(mort10, c('project'), summarise, n=length(project))
#0 missed trees in mort10 subset
#can we just ignore the missed trees? 155 out of 47,102 observations (139 lyford; 6 sim-hurr; 10 hem-history). Yes. Did so.

#####DECISION POINT HERE TYPE VS TYPE2, and MORT VS MORT10#####
condyear1<-ddply(mort, 
                c("project", "plot", "year1", "cond", "type2"), #type
                summarise,
                dens=length(cond),
                size=sum(size)/length(size),
                interval=mean(interval),
                biomass.kg.plot=sum(ifelse(project != 'ems' & cond %in% c('M', 'miss'), biomasspriorAF20,biomassAF20), na.rm=TRUE),
                Rootbiomass.kg.plot=sum(ifelse(project != 'ems' & cond %in% c('M', 'miss'), coarserootKgprior, coarserootKg), na.rm=TRUE),
                IncrementA.kg.plot=sum(ainc, na.rm=TRUE),
                IncrementB.kg.plot=sum(rinc, na.rm=TRUE))

summary(condyear1)
condyear1<-droplevels(condyear1)
condyear1$project<-as.character(condyear1$project)
condyear1$plot<-as.character(condyear1$plot)
summary(condyear1)
condyear1$projplot <- paste(condyear1$project, condyear1$plot, condyear1$year1,sep="")
condyear1$projplot<-as.factor(condyear1$projplot)
#condyear1$year1<-as.factor(condyear1$year1)

# Get a row for each plot/project/year/condition combination.
fillMissingCombs <- function(df, factors, measures) {
  # Make a list of the combinations of factor levels
  levelList <- list()
  for (f in factors) {  levelList[[f]] <- levels(df[,f])  }
  
  fullFactors <- expand.grid(levelList)
  
  dfFull <- merge(fullFactors, df, all.x=TRUE)
  
  # Wherever there is an NA in the measure vars, replace with 0
  for (m in measures) {
    dfFull[is.na(dfFull[,m]), m] <- 0
  }
  return(dfFull)
}
condyear0<-fillMissingCombs(condyear1, factors=c("projplot", 'cond'), 
                            measures=c("dens","interval","biomass.kg.plot", 'Rootbiomass.kg.plot', 
                                       'IncrementA.kg.plot','IncrementB.kg.plot'))
mort1 <- condyear0[order(condyear0$projplot, condyear0$year1),] 
summary(mort1)
mort1$plot.biom.gm2<-(mort1$biomass.kg.plot/mort1$size)*1000
mort1$plot.root.gm2<-(mort1$Rootbiomass.kg.plot/mort1$size)*1000
mort1$plot.incrA.gm2<-(mort1$IncrementA.kg.plot/mort1$size)*1000
mort1$plot.incrB.gm2<-(mort1$IncrementB.kg.plot/mort1$size)*1000
mort1$plot.incrA.gm2[is.na(mort1$plot.incrA.gm2)] <- 0
mort1$plot.incrB.gm2[is.na(mort1$plot.incrB.gm2)] <- 0
mort1$plot.biom.gm2[is.na(mort1$plot.biom.gm2)] <- 0
mort1$plot.root.gm2[is.na(mort1$plot.root.gm2)] <- 0

wide <- reshape(mort1, v.names =c("dens","plot.biom.gm2", 'plot.root.gm2', 'plot.incrA.gm2', 'plot.incrB.gm2'), #"interval", 'plot.incrA.gm2',' plot.incrB.gm2','plot.root.gm2'
                idvar = c('projplot'), timevar = "cond", 
                drop=c('biomass.kg.plot', 'Rootbiomass.kg.plot', 'IncrementA.kg.plot', 'IncrementB.kg.plot'), direction = "wide")
summary(wide)

wide$AboveBiomassStock<-wide$plot.biom.gm2.L +  wide$plot.biom.gm2.R
wide$BelowBiomassStock<-wide$plot.root.gm2.L +  wide$plot.root.gm2.R
wide$TreeANPP<-wide$plot.incrA.gm2.L+wide$plot.incrA.gm2.R
wide$TreeBNPP<-wide$plot.incrB.gm2.L+wide$plot.incrB.gm2.R
wide$annualTreeANPP<-wide$TreeANPP/wide$interval
wide$annualTreeBNPP<-wide$TreeBNPP/wide$interval
wide$annualTreeMortality.gm2<-wide$plot.biom.gm2.M/wide$interval
wide$annualRecruit.gm2<-wide$plot.incrA.gm2.R/wide$interval

#Nov 2018 - use this one to get stocks by project (type) and year?
CStocks<-subset(wide,select= c(project, plot, year1, type2, size, interval, AboveBiomassStock, BelowBiomassStock, plot.biom.gm2.M, plot.root.gm2.M))
CStocks$TreeC<-CStocks$AboveBiomassStock/2
CStocks$CRootC<-CStocks$BelowBiomassStock/2

Cstocksprojyear<-ddply(CStocks, 
                      c("project", "year1"),
                      summarise,
                      n.plots=length(plot),
                      area.m2=sum(size),
                      LiveCA.gm2=mean(TreeC),
                      LiveCA.sd=sd(TreeC),
                      LiveCR.gm2=mean(CRootC),
                      LiveCR.sd=sd(CRootC))

#Just Hemlock
HemC<-subset(CStocks, CStocks$type2=='hemlock' & year1<2016)
HemC<-HemC[,c(1:5,11,12)]
write.table(HemC, 'C:/Users/aabarker/Dropbox/HF C Synthesis/Data/live trees/HemC.csv', sep = ",", row.names = FALSE)


TreeNPP<-subset(wide, select= c(project, plot, year1, type2, size, interval, annualTreeANPP, annualTreeBNPP, annualTreeMortality.gm2, annualRecruit.gm2))
TreeNPP<-subset(TreeNPP, interval!=0)
#here is where E52006, F52006 and F52005 need to get taken out. These 
#are outliers in plot woody ANPP & have known errors in tree diameter measurements.
#see details in spreadsheet file, 'ANPPtroubleshooting.xlsx'
#mean is about 400 g/m2/year, and SD is 278
#pull out numbers >2 SD from mean (let's say >1000 or <0)
#outliers<-subset(TreeANPP, annualTreeANPP>1000 | annualTreeANPP<0)
#there are 26 plot*year outliers, all from EMS. n= 15 of 34 plots.




TreeNPP$plotyear<-paste(TreeNPP$year1,TreeNPP$plot, sep = '')
TreeNPP1<-subset(TreeNPP, !TreeNPP$plotyear %in% c('2006E5', '2006F5', '2005F5'))
mean(TreeNPP1$annualTreeANPP)
sd(TreeNPP1$annualTreeANPP)
str(TreeNPP1)
TreeNPP1$woodyCgm2<-TreeNPP1$annualTreeANPP/2
TreeNPP1$coarserootCgm2<-TreeNPP1$annualTreeBNPP/2
TreeNPP1$deadC<-TreeNPP1$annualTreeMortality.gm2/2
TreeNPP1$recruitCgm2<-TreeNPP1$annualRecruit.gm2/2
plot(as.factor(TreeNPP1$year1), TreeNPP1$deadC)
DeadByYear<-ddply(TreeNPP1, 
                        c("year1", "type2"),
                        summarise,
                        n.plots=length(plot),
                        area.m2=sum(size),
                        dead.gm2=mean(deadC),
                        dead.sd=sd(deadC))
grandDead<-ddply(TreeNPP1, 
                             c("type2"),
                             summarise,
                             n.plots=length(plot),
                             area.m2=sum(size),
                             dead.gm2=mean(deadC),
                             dead.sd=sd(deadC))
grandDRInc<-ddply(TreeNPP1, 
                 c("type2"),
                 summarise,
                 n.plots=length(plot),
                 area.m2=sum(size),
                 grow.gm2=mean(woodyCgm2),
                 grow.sd=sd(woodyCgm2),
                 rec.gm2=mean(recruitCgm2),
                 rec.sd=sd(recruitCgm2),
                 dead.gm2=mean(deadC),
                 dead.sd=sd(deadC))


test<-lm(TreeNPP1$deadC~TreeNPP1$year1)
DeadByYearH<-subset(DeadByYear, DeadByYear$type2=='hardwood')
DeadByYearHem<-subset(DeadByYear, DeadByYear$type2=='hemlock')
test<-lm(DeadByYearC$dead.gm2~DeadByYearC$year1)
summary(test)
summary(DeadByYear)
# subset for hemlock year1 %in% c(1999, 2002, 2009, 2012, 2014)
# subset for hardwood year>1997
str(TreeNPP1)
violin<-ggplot(subset(TreeNPP1, TreeNPP1$year1>1997 & TreeNPP1$type2 !='RP'), aes(x=as.factor(year1), y=deadC, colour=type2, fill=type2))+
  geom_violin()+
  geom_point(aes(y = dead.gm2), color = "black", size = 1, data = subset(DeadByYear,DeadByYear$year1 >1997 & DeadByYear$type2 !='RP')) + 
  theme_bw(base_size = 11)+
  facet_grid(type2~.)+
  scale_x_discrete(breaks=seq(1998,2017,2))+
  theme(panel.grid.major=element_blank(),
        legend.position="none")+
  labs(x="Year", y=expression('plot-level C loss to mortality, C '*g*m^-2*y^-1))

  ggsave("c:/data/FigS4.tiff", violin, width=5, height=3, units = "in", dpi=600, compression = "lzw")
  

ggplot(subset(DeadByYear, DeadByYear$year1 >1997 & DeadByYear$type2 !='RP'), aes(x=year1, y= dead.gm2 ))+ #massgm2 volm3ha
  geom_point(size=4)+
  facet_grid(type2~.)+
  theme_bw(base_size = 18) + 
  # geom_smooth()+
  #geom_errorbar(aes(ymin=volm3ha-vol.sd, ymax=volm3ha+vol.sd), width=0.5) + #, position=position_dodge(.9)
  #facet_grid(type~., scales='free')+ #, scales='free'
  #scale_colour_manual(values=c("#0072B2", "#F0E442","#D55E00","#CC79A7"))+ 
  #scale_x_continuous(breaks=seq(2005,2015,2))+
  labs(x="Year", y=expression('C, '*g*m^-2), title="Average annual inputs of dead hemlock biomass")

#linear regression including 1998-2015 (b/c only one plot prior to this)
TreeNPP1$time<-TreeNPP1$year1-1974
plot(TreeNPP1$time,TreeNPP1$woodyCgm2)
anpptime<-lm(woodyCgm2~time,data=subset(TreeNPP1,  year1>1996&year1<2015&type2=='hardwood' )) #type=='hardwood' &
summary(anpptime)
plot(anpptime)

write.table(TreeNPP1, 'C:/Users/aabarker/Dropbox/HF C Synthesis/Data/live trees/PlotLevelTreeANPP-20nov18.csv', sep = ",", row.names = FALSE)

######CAN START HERE#####
library(ggplot2)
library(plyr)
TreeNPP<-read.csv('C:/Users/aabarker/Dropbox/HF C Synthesis/Data/live trees/PlotLevelTreeANPP-20nov18.csv') #uses cluster
#OR
TreeNPP<-read.csv('C:/data/PlotLevelTreeANPP-10oct17.csv')

str(TreeNPP)
#TreeNPP$year1<-as.factor(TreeNPP$year1)
#plot(TreeNPP$year1, TreeNPP$annualTreeANPP) #barplot if year1 is a factor

treenppsample<-ddply(TreeNPP,
                     c( 'year1','project','type2'), #type
                     summarise,
                     n.plots=length(plot),
                     area.m2=sum(size))

TreeNPP$ABNPPgCm2<-TreeNPP$woodyCgm2+TreeNPP$coarserootCgm2
TreeNPP9814<-subset(TreeNPP, year1>1996 & year1<2015)



TreeNPPbyYear<-ddply(TreeNPP, 
                        c("type2", "year1"),#type
                        summarise,
                        n.plots=length(plot),
                        area.m2=sum(size),
                        ANPPw.mean=mean(woodyCgm2),
                        ANPPw.median=median(woodyCgm2),
                        ANPPw.sd=sd(woodyCgm2),
                        BNPPcr.mean=mean(coarserootCgm2),
                        BNPPcr.median=median(coarserootCgm2),
                        BNPPcr.sd=sd(coarserootCgm2),
                     ABNPP.mean=mean(ABNPPgCm2),
                     ABNPP.median=median(ABNPPgCm2),
                     ABNPP.sd=sd(ABNPPgCm2),
                     dead.mean=mean(deadC),
                     dead.sd=sd(deadC))
write.table(TreeNPPbyYear, 'C:/Users/aabarker/Dropbox/HF C Synthesis/Data/live trees/TreeNPPbyYear20nov18.csv',sep = ",", row.names = FALSE)

TreeNPPoverall<-ddply(TreeNPP9814, 
                     c("type2"),#type
                     summarise,
                     n.plots=length(plot),
                     area.m2=sum(size),
                     ANPPw.mean=mean(woodyCgm2),
                     ANPPw.median=median(woodyCgm2),
                     ANPPw.sd=sd(woodyCgm2),
                     BNPPcr.mean=mean(coarserootCgm2),
                     BNPPcr.median=median(coarserootCgm2),
                     BNPPcr.sd=sd(coarserootCgm2),
                     ABNPP.mean=mean(ABNPPgCm2),
                     ABNPP.median=median(ABNPPgCm2),
                     ABNPP.sd=sd(ABNPPgCm2),
                     recruit.mean=mean(recruitCgm2),
                     recruit.sd=sd(recruitCgm2),
                   dead.mean=mean(deadC),
                   dead.sd=sd(deadC))

#hemlock only for 1999, 2002:2014 (multiple plots)
HemNPP5y<-subset(TreeNPP, TreeNPP$type2=='hemlock' & TreeNPP$year1 %in% c(1999, 2002:2014))
HemNPP<-ddply(HemNPP5y, 
                   c("type2"),#type
                   summarise,
                   n.plots=length(plot),
                   area.m2=sum(size),
                   ANPPw.mean=mean(woodyCgm2),
                   ANPPw.median=median(woodyCgm2),
                   ANPPw.sd=sd(woodyCgm2),
                   BNPPcr.mean=mean(coarserootCgm2),
                   BNPPcr.median=median(coarserootCgm2),
                   BNPPcr.sd=sd(coarserootCgm2),
                   ABNPP.mean=mean(ABNPPgCm2),
                   ABNPP.median=median(ABNPPgCm2),
                   ABNPP.sd=sd(ABNPPgCm2),
                   recruit.mean=mean(recruitCgm2),
                   recruit.sd=sd(recruitCgm2),
              dead.mean=mean(deadC),
              dead.sd=sd(deadC))
write.table(TreeNPPbyYear, 'c:/data/TreeNPPbyYear.csv',sep = ",", row.names = FALSE)

str(TreeNPP)

ggplot(subset(TreeNPP, TreeNPP$type2=='hardwood' & TreeNPP$year1>1996 & TreeNPP$year1<2015), aes(x=year1, y= ABNPPgCm2, group=year1))+ 
  geom_boxplot()+
  theme_bw(base_size = 18) + 
  geom_point( aes(x=year1,y=ABNPPgCm2, color=project),shape=1,position=position_jitter(width=0.4,height=0) )+ #shape=1,position=position_jitter(width=0.5,height=0)
  geom_abline(intercept = 168, slope = 7.8, linetype = 'solid', size = 1, colour ='blue')+
  scale_x_continuous(breaks=seq(1998,2014,2))+
  labs(x="Year", y=expression('C, '*g*m^-2), title="Woody increment (aboveground + coarse roots)")


ggplot(HemNPP5y, aes(x=year1, y= woodyCgm2, group=year1 ))+ 
  geom_boxplot()+
  theme_bw(base_size = 18) + 
  labs(x="Year", y=expression('C, '*g*m^-2), title="Hemlock aboveground woody increment")

#all hardwood plots
TreeNPP$time <-TreeNPP$year1-1997
anpptime<-lm(ABNPPgCm2~time,data=subset(TreeNPP,  year1>1996&year1<2015&type2=='hardwood' )) #type=='hardwood' &
summary(anpptime)
plot(anpptime)
bnpptime<-lm(coarserootCgm2~time,data=subset(TreeNPP,  year1>1996&year1<2015&type2=='hardwood' )) #type=='hardwood' &
summary(bnpptime)
plot(bnpptime)
TreeNPP$deadCln<-log(TreeNPP$deadC+1)
morttime<-lm(deadC~time,data=subset(TreeNPP,  year1>1996&year1<2015&type2=='hardwood' )) #type=='hardwood' &
summary(morttime)
plot(morttime)


#hemlock plots (5 years)
HemNPP5y$time <-HemNPP5y$year1-1998
hemanpptime<-lm(woodyCgm2~time,data=HemNPP5y)
summary(hemanpptime)
plot(hemanpptime)
bnpptime<-lm(coarserootCgm2~time,data=subset(TreeNPP,  year1>1996&year1<2015&type2=='hemlock' )) #type=='hardwood' &
summary(bnpptime)
plot(bnpptime)
TreeNPP$deadCln<-log(TreeNPP$deadC+1)
morttime<-lm(deadC~time,data=HemNPP5y) #type=='hardwood' &
summary(morttime)
plot(morttime)

#ems plots only
emsNPP<-subset(TreeNPP, TreeNPP$project =='ems')
EMSTreeC.NPPbyYear<-ddply(emsNPP, 
                          c("year1", "type2"),
                          summarise,
                          n.plots=length(plot),
                          area.m2=sum(size),
                          ANPPw=mean(woodyCgm2),
                          ANPPw.sd=sd(woodyCgm2),
                          BNPPcr=mean(coarserootCgm2),
                          BNPPcr.sd=sd(coarserootCgm2))

EMSTreeNPPgrandMean<-ddply(emsNPP, 
                           c("project"),
                           summarise,
                           n.plots=length(plot),
                           area.m2=sum(size),
                           ANPPw=mean(woodyCgm2),
                           ANPPw.sd=sd(woodyCgm2),
                           BNPPcr=mean(coarserootCgm2),
                           BNPPcr.sd=sd(coarserootCgm2))

emsanpptime<-lm(woodyCgm2~time, data=emsNPP)
summary(emsanpptime)

#just lyford - only 4 points, so. . . 
lyf<-subset(TreeNPP, TreeNPP$project =='lyford-grid')
lyfanpptime<-lm(woodyCgm2~time, data=lyf)
summary(lyfanpptime)
# no significant slope for the 4 ANPP points from Lyford
plot(lyf$year1,lyf$woodyCgm2)
levels(TreeNPP$project)
overdead<-subset(TreeNPP, TreeNPP$project=='mapped-tree-plot')
plot(overdead$year1,overdead$woodyCgm2)

#HEM tower footprint woody NPP. Use Hemlock woodlot & Hemlock History Plot P2. These 2 plots
#are in the hemlock tower footprint.
#updated 11/19/2018 to add in the 11 hk plots, and restrict time to 2002-2012

HEMtreesA<-subset(TreeNPP, TreeNPP$project %in% c('hemlock-mapped-tree-plot', 'hemlock history', 'hk') & TreeNPP$year1>2001 & TreeNPP$year1<2013)
HEMtrees<-subset(HEMtreesA, !HEMtreesA$plot %in% c('PH7', 'SC9', 'SC10'))
HEMTreeNPPgrandMean<-ddply(HEMtrees, 
                           c("type2"),
                           summarise,
                           n.plots=length(plot),
                           area.m2=sum(size),
                           ANPPw=mean(woodyCgm2),
                           ANPPw.sd=sd(woodyCgm2),
                           BNPPcr=mean(coarserootCgm2),
                           BNPPcr.sd=sd(coarserootCgm2))

hktrees<-subset(TreeNPP, TreeNPP$project %in% c('hk'))

hkTreeNPPgrandMean<-ddply(hktrees, 
                           c("type2"),
                           summarise,
                           n.plots=length(plot),
                           area.m2=sum(size),
                           ANPPw=mean(woodyCgm2),
                           ANPPw.sd=sd(woodyCgm2),
                           BNPPcr=mean(coarserootCgm2),
                           BNPPcr.sd=sd(coarserootCgm2))
