#### put together components and summaries of NPP (excluding fine roots & exudates) ####
## hopefully this will have all the options for publication-ready Fig 4
library(ggplot2)
library(plyr)



#arrange multiple graphs on a page#
library(gridExtra)
pdf("c:/data/foo.pdf")
grid.arrange(panel4a, panel4d,panel4b, panel4e, panel4c, panel4f, ncol=2, nrow=3)
dev.off()
#hw 3 panels only
grid.arrange(panel4a, panel4b, panel4c,ncol=1, nrow=3)
g <- arrangeGrob(panel4a, panel4b, panel4c, ncol=1, nrow=3) #generates g
ggsave("c:/data/Fig4abc.tiff", g, width=6, height=5, units = "in", dpi=600, compression = "lzw")

#hem 3 panels - for supplement
grid.arrange(panel4d, panel4e, panel4f,ncol=1, nrow=3)
g <- arrangeGrob(panel4d, panel4e, panel4f,ncol=1, nrow=3) #generates g
ggsave("c:/data/Fig4def.tiff", g, width=6, height=5, units = "in", dpi=600, compression = "lzw")

###################################
library(RColorBrewer)
brewer.pal(12,'Paired')
pairedcol<-c("#A6CEE3", "#1F78B4" ,"#B2DF8A" ,"#33A02C", "#FB9A99", "#E31A1C", "#FDBF6F",
          "#FF7F00","#CAB2D6", "#6A3D9A","#FFFF99", "#B15928")

# Graph panel 4c (and f, if showing hemlock)
NPPsummary<-read.csv('file:///C:/Users/aabarker/Dropbox/HF C Synthesis/Data/NPPtime20nov2018.csv')
#combined NPP includes aboveground woody increment & coarse root increment, plus total litterfall
#this is for hardwood plots only. mean is summed. sd is sqrt the sum of the squared sd
str(NPPsummary)
#slope is 9.2 for hardwoods, ns for hemlock
NPPsummary$time<-NPPsummary$year-1999
NPPsummaryReg<-lm(CombinedNPP.mean~time, data=subset(NPPsummary, type=='hardwood'& year>1999&year<2015))
summary(NPPsummaryReg)
plot(NPPsummaryReg)
NPPsummary$time<-NPPsummary$year-2001
NPPsummaryHem12<-lm(CombinedNPP.mean~time, data=subset(NPPsummary, type=='hemlock'& year>2001&year<2013))
summary(NPPsummaryHem12)
plot(NPPsummaryHem12)

panel4c<-ggplot(subset(NPPsummary, type=='hardwood'& year>1999&year<2015), aes(x=year, y=CombinedNPP.mean)) + #'hemlock' 'hardwood'
  geom_errorbar(aes(ymin=CombinedNPP.mean-CombinedNPP.sd , ymax=CombinedNPP.mean+CombinedNPP.sd ), width=.1) +
  geom_point(size=3)+
  geom_smooth(method=lm)+ #, se=FALSE
  theme_bw(base_size = 10)+
  theme(legend.background=element_rect(fill='transparent'),  panel.grid.major=element_blank())+
  expand_limits(x = 1998)+
  scale_x_continuous(breaks=seq(1998,2014,2))+
  scale_y_continuous(breaks=seq(250,750,250))+
  annotate("text", x =1998, y = 710, label = "Hardwood NPP, excluding fine roots & root exudates\n slope=9.2", hjust=0, size=3)+ #"Hemlock\n ns"  "Hardwood\n slope=9.2"
  labs(x="Year", y=expression('NPP,  '*gC*m^-2*y^-1 ))#, title="Live Aboveground C - Observational Plots Only")

panel4f<-ggplot(subset(NPPsummary, type=='hemlock'& year>1999&year<2015), aes(x=year, y=CombinedNPP.mean)) + #'hemlock' 'hardwood'
  geom_errorbar(aes(ymin=CombinedNPP.mean-CombinedNPP.sd , ymax=CombinedNPP.mean+CombinedNPP.sd ), width=.1) +
  geom_point(size=3)+
  #geom_smooth(method=lm)+ 
  theme_bw(base_size = 10)+
  theme(legend.background=element_rect(fill='transparent'),  panel.grid.major=element_blank())+
  expand_limits(x = 1998)+
  scale_x_continuous(breaks=seq(1998,2014,2))+
  annotate("text", x =1997.5, y = 650, label = "Hemlock NPP, excluding fine roots \n& root exudates (NS)", hjust=0, size=3)+ #"Hemlock\n ns"  "Hardwood\n slope=9.2"
  labs(x="Year", y=expression('NPP '*gC*m^-2*y^-1))#, title="Live Aboveground C - Observational Plots Only")



##biomass production - panel 4a (d for hemlock)
TreeNPP<-read.csv('file:///C:/Users/aabarker/Dropbox/HF C Synthesis/Data/live trees/PlotLevelTreeANPP-20nov18.csv') #uses cluster
levels(TreeNPP$project)
TreeNPP$ABNPPgCm2<-TreeNPP$woodyCgm2+TreeNPP$coarserootCgm2

#woody NPP boxplots with data points coded by project
#4a colors
panel4a<-ggplot(subset(TreeNPP, TreeNPP$type2=='hardwood' & TreeNPP$year1>1997 & TreeNPP$year1<2015), aes(x=as.factor(year1), y= ABNPPgCm2))+ #, group=year1
  geom_boxplot(outlier.shape=NA)+
  theme_bw(base_size = 10) + 
  geom_point( aes(x=as.factor(year1),y=ABNPPgCm2, color=project),position=position_jitter(width=0.4,height=0))+
  stat_smooth(method=lm, aes(group=1), col='black')+
  scale_color_manual(values=c(colors<-c("#1F78B4" ,"#33A02C",  "#E31A1C", "#FF7F00","#6A3D9A")),
                     name="Project",
                     breaks=c("ems", "hf-here", "lyford-grid", "mapped-tree-plot", "sim-hurricane"),
                     labels=c("EMS Plots", "Hemlock Removal Controls", "Lyford Plot", "Mapped Tree Plots", "Simulated Hurricane Control")
                     ,guide=FALSE)+ 
  theme(axis.title.x=element_blank(),
        axis.text.x=element_blank(),
        axis.ticks.x=element_blank(), legend.background=element_rect(fill='transparent'),  panel.grid.major=element_blank())+
  #scale_x_discrete(breaks=seq(1998,2014,2))+
  scale_y_continuous(breaks=seq(0,999,300))+
  #geom_abline(aes(intercept= 168, slope = 7.8), linetype = 'solid', size = 2, colour ='black')+
  annotate("text", x="1998", y = 850, label = "Hardwood biomass increment, excluding fine root increment\n slope=7.8"  ,size=3, hjust=0)+ #"Hemlock\n ns"  "Hardwood\n slope=9.2"
  #theme(legend.position = "bottom") +
  labs(x="", y=expression('Increment,  '*gC*m^-2*y^-1))#, title="Woody increment (aboveground + coarse roots)"

#4d
panel4d<-ggplot(subset(TreeNPP, TreeNPP$type2=='hemlock' &  TreeNPP$year1 %in% c(1999, 2002:2014)), aes(x=year1, y= ABNPPgCm2, group=year1))+ #, group=year1
  geom_boxplot(outlier.shape=NA)+
  theme_bw(base_size = 10) + 
  geom_point( aes(x=year1,y=ABNPPgCm2, color=project),position=position_jitter(width=0.4,height=0))+
  scale_color_manual(values=c(colors<-c("#1F78B4","#E31A1C","#FF7F00","#33A02C","#6A3D9A")),
                     name="Project",
                     breaks=c("ems",  "hemlock-mapped-tree-plot","hemlock history", "hf-here", "hk"),
                     labels=c("EMS Plots","HEM Grid",  "Hemlock History", "Hemlock Removal Controls","HEM dendro"),
                     guide=FALSE)+
  expand_limits(x = 1998)+
 # scale_x_continuous(breaks=seq(1998,2014,2))+
  theme(axis.title.x=element_blank(),
        axis.text.x=element_blank(),
        axis.ticks.x=element_blank(), legend.background=element_rect(fill='transparent'),  panel.grid.major=element_blank())+
    annotate("text", x=1998, y = 725, label = "Hemlock biomass increment, excluding fine root increment\n ns",size=3, hjust=0)+ #"Hemlock\n ns"  "Hardwood\n slope=9.2"
  theme(legend.position = "bottom") + 
   labs(y=expression('Increment, '*gC*m^-2*y^-1))#, title="Woody increment (aboveground + coarse roots)"

#litter NPP
all_litter<-read.csv("C:/Users/aabarker/Dropbox/HF C Synthesis/Data/litterfall/hf-c-litter-nov2017.csv")
#hardwood vs. hemlock is okay, except for those 5 EMS tower plots. What if those are re-classified?
all_litter$type2<-ifelse(all_litter$plot %in% c('E5','G2'), 'conifer', ifelse(all_litter$plot %in% c('E2','F1','G1'),NA, ifelse(all_litter$type=='hardwood', 'hardwood', 'conifer')))
levels(all_litter$project)

### FOLIAR LITTER ###
FolLitObs<-subset(all_litter, !is.na (all_litter$FoliargCm2)& all_litter$obs.exp=='obs')
#take out Chronic N RP plots
FolLitObs<-subset(FolLitObs, !FolLitObs$plot %in% c('PC'))
FolLitObs$time<-FolLitObs$year-1997
FolHWtime<-lm(FoliargCm2~time, data=subset(FolLitObs, type2=='hardwood'& year>1997&year<2015))
summary(FolHWtime)
plot(FolHWtime)



### TOTAL LITTER (foliar & woody). Observational only, no Chronic C RP
TotLitObs<-subset(all_litter, !is.na (all_litter$TotalgCm2)& all_litter$obs.exp=='obs' & !all_litter$plot %in% c('PC'))
TotLitObs$time<-TotLitObs$year-1997

# panel 4b - foliar litter, hardwoods, colors
panel4b<-ggplot(subset(FolLitObs, FolLitObs$type2=='hardwood' & FolLitObs$year>1997 & FolLitObs$year<2015), aes(x=as.factor(year), y= FoliargCm2 ))+ #TotalgCm2  FoliargCm2
  geom_boxplot(outlier.shape=NA)+
  theme_bw(base_size = 10) + 
  geom_point( aes(x=as.factor(year),y=FoliargCm2, color=project),position=position_jitter(width=0.4,height=0))+
  stat_smooth(method=lm, aes(group=1), col='black')+
  scale_color_manual(values=c("#A6CEE3","#B2DF8A", "#1F78B4" ,"#FB9A99","#33A02C","#FDBF6F" ,"#B15928" ),
                     name="Project",
                     breaks=c("barre-woods","chronicN","ems", "hem-chrono","hf-here", "lph", "prot-enz"),
                     labels=c("Soil Warming", "Chronic N", "EMS plots", "Hemlock Chronosequence", "Hemlock Removal Controls", "Little Prospect Hill", "Soil Enzyme Plots") 
                     ,guide=FALSE)+
  theme(axis.title.x=element_blank(),
        axis.text.x=element_blank(),
        axis.ticks.x=element_blank(), legend.background=element_rect(fill='transparent'),  panel.grid.major=element_blank())+
  #  scale_x_discrete(breaks=seq(1998,2014,2))+
  #geom_abline(aes(intercept= 136, slope = 2.26), linetype = 'solid', size = 2, colour ='black')+
  annotate("text", x="1998", y = 305, label = "Hardwood foliar turnover\n slope=2.3",size=3, hjust=0)+ #"Hemlock\n ns"  "Hardwood\n slope=9.2"
  #theme(legend.position = "bottom") +
  labs(y=expression('Foliar litterfall,  '*gC*m^-2*y^-1))

#4b shapes
# scale_shape_manual(values=c(4, 11, 111, 9, 0, 76, 13),
#                    name="Project",
#                    breaks=c("barre-woods","chronicN","ems", "hem-chrono","hf-here", "lph", "prot-enz"),
#                    labels=c("Soil Warming", "Chronic N", "EMS plots", "Hemlock Chronosequence", "Hemlock Removal Controls", "Little Prospect Hill", "Soil Enzyme Plots") 
#                    

#panel 4e hemlock foliar litter
panel4e<-ggplot(subset(FolLitObs, FolLitObs$type2=='conifer' & FolLitObs$year>2004 & FolLitObs$year<2015), aes(x=year, y= FoliargCm2, group=year ))+ #TotalgCm2  FoliargCm2
  geom_boxplot(outlier.shape=NA)+
  theme_bw(base_size = 10) + 
  geom_point( aes(x=year,y=FoliargCm2, color=project),position=position_jitter(width=0.4,height=0))+
  scale_color_manual(values=c('#1F78B4',"#FB9A99",'#33A02C','#6A3D9A','#B15928'),
                     name="Project",
                     breaks=c("ems", "hem-chrono","hf-here", "hk", "prot-enz"),
                     labels=c("EMS plots", "Hemlock Chronosequence", "Hemlock Removal Controls", "HEM Tower", "Soil Enzyme Plots"), 
                     guide=FALSE)+
  theme(axis.title.x=element_blank(),
        axis.text.x=element_blank(),
        axis.ticks.x=element_blank(), legend.background=element_rect(fill='transparent'),  panel.grid.major=element_blank())+
  expand_limits(x = 1998)+
  #scale_x_continuous(breaks=seq(1998,2014,2))+
  annotate("text", x=1998, y = 370, label = "Hemlock foliar turnover\n ns",size=3, hjust=0)+ #"Hemlock\n ns"  "Hardwood\n slope=9.2"
  theme(legend.position = "bottom") +
  labs(x="Year", y=expression('Foliar litterfall, '*gC*m^-2*y^-1))

# make a legend for ALL the projects. . . 
# poo<-c("Soil Warming", "Chronic N", "EMS plots", "Hemlock Chronosequence", "HEM Grid",  "Hemlock History",
#        "Hemlock Removal Controls", "HEM tower","Little Prospect Hill", "Lyford Plot", 
#        "Mapped Tree Plots","Soil Enzyme Plots", "Simulated Hurricane Control") 
# shapes<-c(4, 11, 111, 9, 7, 6, 0, 3, 76,1, 2, 13, 5 )
# num<-c(1:13)
# leghem<-as.data.frame(cbind(poo,shapes,num))
# leghem$poo <- factor(leg$poo, levels = c("Soil Warming", "Chronic N", "EMS plots", "Hemlock Chronosequence", "HEM Grid",  "Hemlock History",
#                                       "Hemlock Removal Controls", "HEM tower","Little Prospect Hill", "Lyford Plot", 
#                                       "Mapped Tree Plots","Soil Enzyme Plots", "Simulated Hurricane Control") )

#Hardwoods, colors
pooh<-c("Soil Warming", "Chronic N", "EMS plots", "Hemlock Chronosequence", "Hemlock Removal Controls", 
        "Little Prospect Hill", "Lyford Plot", 
        "Mapped Tree Plots","Soil Enzyme Plots", "Simulated Hurricane Control") 
mycolors<-c("#A6CEE3", "#B2DF8A" ,"#1F78B4" ,"#FB9A99","#33A02C", "#FDBF6F","#E31A1C", "#FF7F00",
            "#B15928", "#6A3D9A")
numh<-c(1:10)
leg<-as.data.frame(cbind(pooh,mycolors,numh))
leg$pooh <- factor(leg$pooh, levels =c("Soil Warming", "Chronic N", "EMS plots", "Hemlock Chronosequence", "Hemlock Removal Controls", 
                                     "Little Prospect Hill", "Lyford Plot", 
                                     "Mapped Tree Plots","Soil Enzyme Plots", "Simulated Hurricane Control"))

#Hemlocks, colors                  
poohem<-c("EMS Plots","HEM Grid",  "Hemlock History", "Hemlock Removal Controls","HEM dendro","Hemlock Chronosequence","Soil Enzyme Plots") 
mycolorshem<-c("#1F78B4","#E31A1C", "#FF7F00", "#33A02C", "#6A3D9A","#FB9A99", "#B15928")
numhem<-c(1:7)
leghem<-as.data.frame(cbind(poohem,mycolorshem,numhem))
leghem$poohem <- factor(leghem$poohem, levels =c("EMS Plots","HEM Grid",  "Hemlock History", "Hemlock Removal Controls","HEM Dendro","Hemlock Chronosequence","Soil Enzyme Plots"))


legcolor<-ggplot(leg, aes(x=pooh, y= numh))+ 
  theme_bw(base_size = 15) + 
  geom_point( aes(x=pooh,y=numh, color=pooh))+
  scale_color_manual(values=mycolors,
                     name="",
                     breaks=pooh,
                     labels=pooh)+
  theme(legend.position = "bottom") + guides(col=guide_legend(nrow=2,byrow=TRUE))

#extract legend as an object called 'legend' (can change!)
tmp <- ggplot_gtable(ggplot_build(legcolor))
leg <- which(sapply(tmp$grobs, function(x) x$name) ==  "guide-box")
legend <- tmp$grobs[[leg]]

legshapeHEM<-ggplot(leghem, aes(x=poohem, y= numhem))+ 
  theme_bw(base_size = 12) + 
  geom_point( aes(x=poohem,y=numhem, color=poohem))+
  scale_color_manual(values=mycolorshem,
                     name="",
                     breaks=poohem,
                     labels=poohem)+
  theme(legend.position = "bottom")
+ guides(fill=guide_legend(nrow=3,byrow=TRUE))

